@@ -1,10 +1,9 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
 Package contains pure python neuroimaging algorithms
 
-Exaples: artifactdetect
+Examples: artifactdetect
 
 """
 __docformat__ = "restructuredtext"
