@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Miscellaneous algorithms."""
@@ -24,6 +23,7 @@ from ..interfaces.base import (
     isdefined,
     DynamicTraitedSpec,
     Undefined,
+    Tuple,
 )
 from ..utils.filemanip import fname_presuffix, split_filename, ensure_list
 
@@ -494,7 +494,7 @@ def merge_csvs(in_list):
             try:
                 in_array = np.loadtxt(in_file, delimiter=",", skiprows=1)
             except ValueError:
-                with open(in_file, "r") as first:
+                with open(in_file) as first:
                     header_line = first.readline()
 
                 header_list = header_line.split(",")
@@ -532,7 +532,7 @@ def remove_identical_paths(in_files):
         commonprefix = op.commonprefix(in_files)
         lastslash = commonprefix.rfind("/")
         commonpath = commonprefix[0 : (lastslash + 1)]
-        for fileidx, in_file in enumerate(in_files):
+        for in_file in in_files:
             path, name, ext = split_filename(in_file)
             in_file = op.join(path, name)
             name = in_file.replace(commonpath, "")
@@ -549,11 +549,9 @@ def maketypelist(rowheadings, shape, extraheadingBool, extraheading):
     if rowheadings:
         typelist.append(("heading", "a40"))
     if len(shape) > 1:
-        for idx in range(1, (min(shape) + 1)):
-            typelist.append((str(idx), float))
+        typelist.extend((str(idx), float) for idx in range(1, (min(shape) + 1)))
     else:
-        for idx in range(1, (shape[0] + 1)):
-            typelist.append((str(idx), float))
+        typelist.extend((str(idx), float) for idx in range(1, (shape[0] + 1)))
     if extraheadingBool:
         typelist.append((extraheading, "a40"))
     iflogger.info(typelist)
@@ -669,9 +667,9 @@ class MergeCSVFiles(BaseInterface):
 
         if isdefined(self.inputs.row_headings):
             iflogger.info(
-                'Row headings have been provided. Adding "labels"' "column header."
+                'Row headings have been provided. Adding "labels" column header.'
             )
-            prefix = '"{p}","'.format(p=self.inputs.row_heading_title)
+            prefix = f'"{self.inputs.row_heading_title}","'
             csv_headings = prefix + '","'.join(itertools.chain(headings)) + '"\n'
             rowheadingsBool = True
         else:
@@ -686,7 +684,7 @@ class MergeCSVFiles(BaseInterface):
 
         output_array = merge_csvs(self.inputs.in_files)
         _, name, ext = split_filename(self.inputs.out_file)
-        if not ext == ".csv":
+        if ext != ".csv":
             ext = ".csv"
 
         out_file = op.abspath(name + ext)
@@ -714,8 +712,7 @@ class MergeCSVFiles(BaseInterface):
                 mx = shape[0]
             else:
                 mx = 1
-            for idx in range(0, mx):
-                extrafieldlist.append(self.inputs.extra_field)
+            extrafieldlist.extend(self.inputs.extra_field for idx in range(mx))
             iflogger.info(len(extrafieldlist))
             output[extraheading] = extrafieldlist
         iflogger.info(output)
@@ -728,7 +725,7 @@ class MergeCSVFiles(BaseInterface):
     def _list_outputs(self):
         outputs = self.output_spec().get()
         _, name, ext = split_filename(self.inputs.out_file)
-        if not ext == ".csv":
+        if ext != ".csv":
             ext = ".csv"
         out_file = op.abspath(name + ext)
         outputs["csv_file"] = out_file
@@ -772,9 +769,9 @@ class AddCSVColumn(BaseInterface):
     output_spec = AddCSVColumnOutputSpec
 
     def _run_interface(self, runtime):
-        in_file = open(self.inputs.in_file, "r")
+        in_file = open(self.inputs.in_file)
         _, name, ext = split_filename(self.inputs.out_file)
-        if not ext == ".csv":
+        if ext != ".csv":
             ext = ".csv"
         out_file = op.abspath(name + ext)
 
@@ -794,7 +791,7 @@ class AddCSVColumn(BaseInterface):
     def _list_outputs(self):
         outputs = self.output_spec().get()
         _, name, ext = split_filename(self.inputs.out_file)
-        if not ext == ".csv":
+        if ext != ".csv":
             ext = ".csv"
         out_file = op.abspath(name + ext)
         outputs["csv_file"] = out_file
@@ -808,12 +805,12 @@ class AddCSVRowInputSpec(DynamicTraitedSpec, BaseInterfaceInputSpec):
     def __setattr__(self, key, value):
         if key not in self.copyable_trait_names():
             if not isdefined(value):
-                super(AddCSVRowInputSpec, self).__setattr__(key, value)
+                super().__setattr__(key, value)
             self._outputs[key] = value
         else:
             if key in self._outputs:
                 self._outputs[key] = value
-            super(AddCSVRowInputSpec, self).__setattr__(key, value)
+            super().__setattr__(key, value)
 
 
 class AddCSVRowOutputSpec(TraitedSpec):
@@ -850,7 +847,7 @@ class AddCSVRow(BaseInterface):
     output_spec = AddCSVRowOutputSpec
 
     def __init__(self, infields=None, force_run=True, **kwargs):
-        super(AddCSVRow, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         undefined_traits = {}
         self._infields = infields
         self._have_lock = False
@@ -871,7 +868,7 @@ class AddCSVRow(BaseInterface):
             import pandas as pd
         except ImportError as e:
             raise ImportError(
-                "This interface requires pandas " "(http://pandas.pydata.org/) to run."
+                "This interface requires pandas (http://pandas.pydata.org/) to run."
             ) from e
 
         try:
@@ -882,10 +879,8 @@ class AddCSVRow(BaseInterface):
             from warnings import warn
 
             warn(
-                (
-                    "Python module filelock was not found: AddCSVRow will not be"
-                    " thread-safe in multi-processor execution"
-                )
+                "Python module filelock was not found: AddCSVRow will not be"
+                " thread-safe in multi-processor execution"
             )
 
         input_dict = {}
@@ -926,7 +921,7 @@ class AddCSVRow(BaseInterface):
         return outputs
 
     def _outputs(self):
-        return self._add_output_traits(super(AddCSVRow, self)._outputs())
+        return self._add_output_traits(super()._outputs())
 
     def _add_output_traits(self, base):
         return base
@@ -1003,7 +998,7 @@ class AddNoiseInputSpec(TraitedSpec):
     )
     in_mask = File(
         exists=True,
-        desc=("input mask, voxels outside this mask " "will be considered background"),
+        desc=("input mask, voxels outside this mask will be considered background"),
     )
     snr = traits.Float(10.0, desc="desired output SNR in dB", usedefault=True)
     dist = traits.Enum(
@@ -1018,7 +1013,7 @@ class AddNoiseInputSpec(TraitedSpec):
         "rayleigh",
         usedefault=True,
         mandatory=True,
-        desc=("desired noise distribution, currently " "only normal is implemented"),
+        desc=("desired noise distribution, currently only normal is implemented"),
     )
     out_file = File(desc="desired output filename")
 
@@ -1070,7 +1065,7 @@ class AddNoise(BaseInterface):
     def _gen_output_filename(self):
         if not isdefined(self.inputs.out_file):
             _, base, ext = split_filename(self.inputs.in_file)
-            out_file = os.path.abspath("%s_SNR%03.2f%s" % (base, self.inputs.snr, ext))
+            out_file = os.path.abspath(f"{base}_SNR{self.inputs.snr:03.2f}{ext}")
         else:
             out_file = self.inputs.out_file
 
@@ -1121,7 +1116,7 @@ class AddNoise(BaseInterface):
             im_noise = np.sqrt((image + stde_1) ** 2 + (stde_2) ** 2)
         else:
             raise NotImplementedError(
-                ("Only normal and rician distributions " "are supported")
+                "Only normal and rician distributions are supported"
             )
 
         return im_noise
@@ -1179,7 +1174,7 @@ class NormalizeProbabilityMapSet(BaseInterface):
 class SplitROIsInputSpec(TraitedSpec):
     in_file = File(exists=True, mandatory=True, desc="file to be split")
     in_mask = File(exists=True, desc="only process files inside mask")
-    roi_size = traits.Tuple(traits.Int, traits.Int, traits.Int, desc="desired ROI size")
+    roi_size = Tuple(traits.Int, traits.Int, traits.Int, desc="desired ROI size")
 
 
 class SplitROIsOutputSpec(TraitedSpec):
@@ -1350,7 +1345,7 @@ def split_rois(in_file, mask=None, roishape=None):
     """
     import nibabel as nb
     import numpy as np
-    from math import sqrt, ceil
+    from math import ceil
     import os.path as op
 
     if roishape is None:
@@ -1547,7 +1542,7 @@ class CalculateMedian(BaseInterface):
     output_spec = CalculateMedianOutputSpec
 
     def __init__(self, *args, **kwargs):
-        super(CalculateMedian, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self._median_files = []
 
     def _gen_fname(self, suffix, idx=None, ext=None):
@@ -1569,10 +1564,10 @@ class CalculateMedian(BaseInterface):
         if self.inputs.median_file:
             outname = self.inputs.median_file
         else:
-            outname = "{}_{}".format(fname, suffix)
+            outname = f"{fname}_{suffix}"
         if idx:
             outname += str(idx)
-        return op.abspath("{}.{}".format(outname, ext))
+        return op.abspath(f"{outname}.{ext}")
 
     def _run_interface(self, runtime):
         total = None
