@@ -5,7 +5,7 @@ docs.  In setup.py in particular, we exec this file, so it cannot import nipy
 
 # nipype version information
 # Remove .dev0 for release
-__version__ = "1.9.0"
+__version__ = "1.9.2"
 
 
 def get_nipype_gitversion():
@@ -58,6 +58,7 @@ CLASSIFIERS = [
     "Programming Language :: Python :: 3.10",
     "Programming Language :: Python :: 3.11",
     "Programming Language :: Python :: 3.12",
+    "Programming Language :: Python :: 3.13",
     "Topic :: Scientific/Engineering",
 ]
 PYTHON_REQUIRES = ">= 3.9"
@@ -99,12 +100,11 @@ existing pipeline systems.
 """
 
 # versions
-NIBABEL_MIN_VERSION = "2.1.0"
-NETWORKX_MIN_VERSION = "2.0"
-NUMPY_MIN_VERSION = "1.17"
-NUMPY_MAX_VERSION = "2.0"
-SCIPY_MIN_VERSION = "0.14"
-TRAITS_MIN_VERSION = "4.6"
+NIBABEL_MIN_VERSION = "3.0"
+NETWORKX_MIN_VERSION = "2.5"
+NUMPY_MIN_VERSION = "1.21"
+SCIPY_MIN_VERSION = "1.8"
+TRAITS_MIN_VERSION = "6.2"
 DATEUTIL_MIN_VERSION = "2.2"
 SIMPLEJSON_MIN_VERSION = "3.8.0"
 PROV_MIN_VERSION = "1.5.2"
@@ -136,7 +136,7 @@ REQUIRES = [
     "click>=%s" % CLICK_MIN_VERSION,
     "networkx>=%s" % NETWORKX_MIN_VERSION,
     "nibabel>=%s" % NIBABEL_MIN_VERSION,
-    "numpy>=%s,<%s" % (NUMPY_MIN_VERSION, NUMPY_MAX_VERSION),
+    "numpy>=%s" % NUMPY_MIN_VERSION,
     "packaging",
     "prov>=%s" % PROV_MIN_VERSION,
     "pydot>=%s" % PYDOT_MIN_VERSION,
@@ -144,22 +144,24 @@ REQUIRES = [
     "rdflib>=%s" % RDFLIB_MIN_VERSION,
     "scipy>=%s" % SCIPY_MIN_VERSION,
     "simplejson>=%s" % SIMPLEJSON_MIN_VERSION,
-    "traits>=%s,!=5.0" % TRAITS_MIN_VERSION,
+    "traits>=%s" % TRAITS_MIN_VERSION,
     "filelock>=3.0.0",
-    "etelemetry>=0.2.0",
+    "acres",
+    "etelemetry>=0.3.1",
     "looseversion!=1.2",
     "puremagic",
 ]
 
 TESTS_REQUIRES = [
-    "codecov",
-    "coverage",
-    "pytest",
-    "pytest-cov",
+    "coverage >= 5.2.1",
+    "pandas >= 1.5.0",
+    "pytest >= 6",
+    "pytest-cov >=2.11",
     "pytest-env",
-    "pytest-timeout",
+    "pytest-timeout >=1.4",
     "pytest-doctestplus",
-    "sphinx",
+    "pytest-xdist >= 2.5",
+    "sphinx >=7",
 ]
 
 EXTRA_REQUIRES = {
