@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft = python sts = 4 ts = 4 sw = 4 et:
 """
@@ -13,25 +12,19 @@ See the docstrings of the individual classes for examples.
 import os
 
 from ..base import (
-    CommandLineInputSpec,
-    CommandLine,
-    Directory,
     TraitedSpec,
     traits,
     isdefined,
     File,
     InputMultiPath,
-    Undefined,
     Str,
+    Tuple,
 )
-from ...external.due import BibTeX
 
 from .base import (
-    AFNICommandBase,
     AFNICommand,
     AFNICommandInputSpec,
     AFNICommandOutputSpec,
-    Info,
 )
 
 
@@ -128,7 +121,7 @@ class DeconvolveInputSpec(AFNICommandInputSpec):
         "that 'gotforit' is needed to ignore.",
         argstr="-allzero_OK",
     )
-    dname = traits.Tuple(
+    dname = Tuple(
         Str, Str, desc="set environmental variable to provided value", argstr="-D%s=%s"
     )
     mask = File(
@@ -163,7 +156,7 @@ class DeconvolveInputSpec(AFNICommandInputSpec):
         "[default: 1]",
         argstr="-polort %d",
     )
-    ortvec = traits.Tuple(
+    ortvec = Tuple(
         File(desc="filename", exists=True),
         Str(desc="label"),
         desc="this option lets you input a rectangular array of 1 or more "
@@ -197,7 +190,7 @@ class DeconvolveInputSpec(AFNICommandInputSpec):
         desc="output the sample variance (MSE) for each stimulus", argstr="-vout"
     )
     nofdr = traits.Bool(
-        desc="Don't compute the statistic-vs-FDR curves for the bucket " "dataset.",
+        desc="Don't compute the statistic-vs-FDR curves for the bucket dataset.",
         argstr="-noFDR",
     )
     global_times = traits.Bool(
@@ -214,19 +207,17 @@ class DeconvolveInputSpec(AFNICommandInputSpec):
         desc="number of stimulus timing files", argstr="-num_stimts %d", position=-6
     )
     stim_times = traits.List(
-        traits.Tuple(
+        Tuple(
             traits.Int(desc="k-th response model"),
             File(desc="stimulus timing file", exists=True),
             Str(desc="model"),
         ),
-        desc="generate a response model from a set of stimulus times" " given in file.",
+        desc="generate a response model from a set of stimulus times given in file.",
         argstr="-stim_times %d %s '%s'...",
         position=-5,
     )
     stim_label = traits.List(
-        traits.Tuple(
-            traits.Int(desc="k-th input stimulus"), Str(desc="stimulus label")
-        ),
+        Tuple(traits.Int(desc="k-th input stimulus"), Str(desc="stimulus label")),
         desc="label for kth input stimulus (e.g., Label1)",
         argstr="-stim_label %d %s...",
         requires=["stim_times"],
@@ -252,9 +243,7 @@ class DeconvolveInputSpec(AFNICommandInputSpec):
         position=-2,
     )
     glt_label = traits.List(
-        traits.Tuple(
-            traits.Int(desc="k-th general linear test"), Str(desc="GLT label")
-        ),
+        Tuple(traits.Int(desc="k-th general linear test"), Str(desc="GLT label")),
         desc="general linear test (i.e., contrast) labels",
         argstr="-glt_label %d %s...",
         requires=["gltsym"],
@@ -305,7 +294,7 @@ class Deconvolve(AFNICommand):
                 if val.startswith("SYM: "):
                     value[n] = val.lstrip("SYM: ")
 
-        return super(Deconvolve, self)._format_arg(name, trait_spec, value)
+        return super()._format_arg(name, trait_spec, value)
 
     def _parse_inputs(self, skip=None):
         if skip is None:
@@ -317,7 +306,7 @@ class Deconvolve(AFNICommand):
         if not isdefined(self.inputs.out_file):
             self.inputs.out_file = "Decon.nii"
 
-        return super(Deconvolve, self)._parse_inputs(skip)
+        return super()._parse_inputs(skip)
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
@@ -489,9 +478,7 @@ class RemlfitInputSpec(AFNICommandInputSpec):
         argstr="-nobout",
     )
     gltsym = traits.List(
-        traits.Either(
-            traits.Tuple(File(exists=True), Str()), traits.Tuple(Str(), Str())
-        ),
+        traits.Either(Tuple(File(exists=True), Str()), Tuple(Str(), Str())),
         desc="read a symbolic GLT from input file and associate it with a "
         "label. As in Deconvolve, you can also use the 'SYM:' method "
         "to provide the definition of the GLT directly as a string "
@@ -570,14 +557,14 @@ class RemlfitInputSpec(AFNICommandInputSpec):
 
 class RemlfitOutputSpec(AFNICommandOutputSpec):
     out_file = File(
-        desc="dataset for beta + statistics from the REML estimation (if " "generated"
+        desc="dataset for beta + statistics from the REML estimation (if generated)"
     )
     var_file = File(desc="dataset for REML variance parameters (if generated)")
     rbeta_file = File(
-        desc="dataset for beta weights from the REML estimation (if " "generated)"
+        desc="dataset for beta weights from the REML estimation (if generated)"
     )
     rbeta_file = File(
-        desc="output dataset for beta weights from the REML estimation (if " "generated"
+        desc="output dataset for beta weights from the REML estimation (if generated)"
     )
     glt_file = File(
         desc="output dataset for beta + statistics from the REML estimation, "
@@ -586,7 +573,7 @@ class RemlfitOutputSpec(AFNICommandOutputSpec):
     )
     fitts_file = File(desc="output dataset for REML fitted model (if generated)")
     errts_file = File(
-        desc="output dataset for REML residuals = data - fitted model (if " "generated"
+        desc="output dataset for REML residuals = data - fitted model (if generated)"
     )
     wherr_file = File(
         desc="dataset for REML residual, whitened using the estimated "
@@ -594,17 +581,17 @@ class RemlfitOutputSpec(AFNICommandOutputSpec):
     )
     ovar = File(desc="dataset for OLSQ st.dev. parameter (if generated)")
     obeta = File(
-        desc="dataset for beta weights from the OLSQ estimation (if " "generated)"
+        desc="dataset for beta weights from the OLSQ estimation (if generated)"
     )
     obuck = File(
-        desc="dataset for beta + statistics from the OLSQ estimation (if " "generated)"
+        desc="dataset for beta + statistics from the OLSQ estimation (if generated)"
     )
     oglt = File(
-        desc="dataset for beta + statistics from 'gltsym' options (if " "generated"
+        desc="dataset for beta + statistics from 'gltsym' options (if generated)"
     )
     ofitts = File(desc="dataset for OLSQ fitted model (if generated)")
     oerrts = File(
-        desc="dataset for OLSQ residuals = data - fitted model (if " "generated"
+        desc="dataset for OLSQ residuals = data - fitted model (if generated)"
     )
 
 
@@ -637,12 +624,12 @@ class Remlfit(AFNICommand):
     def _parse_inputs(self, skip=None):
         if skip is None:
             skip = []
-        return super(Remlfit, self)._parse_inputs(skip)
+        return super()._parse_inputs(skip)
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
 
-        for key in outputs.keys():
+        for key in outputs:
             if isdefined(self.inputs.get()[key]):
                 outputs[key] = os.path.abspath(self.inputs.get()[key])
 
@@ -651,13 +638,13 @@ class Remlfit(AFNICommand):
 
 class SynthesizeInputSpec(AFNICommandInputSpec):
     cbucket = File(
-        desc="Read the dataset output from " "3dDeconvolve via the '-cbucket' option.",
+        desc="Read the dataset output from 3dDeconvolve via the '-cbucket' option.",
         argstr="-cbucket %s",
         copyfile=False,
         mandatory=True,
     )
     matrix = File(
-        desc="Read the matrix output from " "3dDeconvolve via the '-x1D' option.",
+        desc="Read the matrix output from 3dDeconvolve via the '-x1D' option.",
         argstr="-matrix %s",
         copyfile=False,
         mandatory=True,
@@ -682,7 +669,7 @@ class SynthesizeInputSpec(AFNICommandInputSpec):
         argstr="-prefix %s",
     )
     dry_run = traits.Bool(
-        desc="Don't compute the output, just " "check the inputs.", argstr="-dry"
+        desc="Don't compute the output, just check the inputs.", argstr="-dry"
     )
     TR = traits.Float(
         desc="TR to set in the output.  The default value of "
@@ -728,7 +715,7 @@ class Synthesize(AFNICommand):
     def _list_outputs(self):
         outputs = self.output_spec().get()
 
-        for key in outputs.keys():
+        for key in outputs:
             if isdefined(self.inputs.get()[key]):
                 outputs[key] = os.path.abspath(self.inputs.get()[key])
 
