@@ -1,12 +1,9 @@
-# -*- coding: utf-8 -*-
 """ANTS Legacy Interfaces
 
 These interfaces are for programs that have been deprecated by ANTs, but
 are preserved for backwards compatibility.
 """
 
-from builtins import range
-
 import os
 from glob import glob
 
@@ -40,7 +37,7 @@ class antsIntroductionInputSpec(ANTSCommandInputSpec):
     )
     force_proceed = traits.Bool(
         argstr="-f 1",
-        desc=("force script to proceed even if headers " "may be incompatible"),
+        desc=("force script to proceed even if headers may be incompatible"),
     )
     inverse_warp_template_labels = traits.Bool(
         argstr="-l",
@@ -63,7 +60,7 @@ class antsIntroductionInputSpec(ANTSCommandInputSpec):
         ),
     )
     bias_field_correction = traits.Bool(
-        argstr="-n 1", desc=("Applies bias field correction to moving " "image")
+        argstr="-n 1", desc=("Applies bias field correction to moving image")
     )
     similarity_metric = traits.Enum(
         "PR",
@@ -101,7 +98,7 @@ class antsIntroductionInputSpec(ANTSCommandInputSpec):
         "ants_",
         argstr="-o %s",
         usedefault=True,
-        desc=("Prefix that is prepended to all output " "files (default = ants_)"),
+        desc=("Prefix that is prepended to all output files (default = ants_)"),
     )
     quality_check = traits.Bool(
         argstr="-q 1", desc="Perform a quality check of the result"
@@ -188,7 +185,7 @@ class buildtemplateparallelInputSpec(ANTSCommandInputSpec):
         "antsTMPL_",
         argstr="-o %s",
         usedefault=True,
-        desc=("Prefix that is prepended to all output " "files (default = antsTMPL_)"),
+        desc=("Prefix that is prepended to all output files (default = antsTMPL_)"),
     )
     in_files = traits.List(
         File(exists=True),
@@ -211,7 +208,7 @@ class buildtemplateparallelInputSpec(ANTSCommandInputSpec):
     )
     gradient_step_size = traits.Float(
         argstr="-g %f",
-        desc=("smaller magnitude results in " "more cautious steps (default = " ".25)"),
+        desc=("smaller magnitude results in more cautious steps (default = .25)"),
     )
     iteration_limit = traits.Int(
         4, argstr="-i %d", usedefault=True, desc="iterations of template construction"
@@ -219,9 +216,7 @@ class buildtemplateparallelInputSpec(ANTSCommandInputSpec):
     num_cores = traits.Int(
         argstr="-j %d",
         requires=["parallelization"],
-        desc=(
-            "Requires parallelization = 2 (PEXEC). " "Sets number of cpu cores to use"
-        ),
+        desc=("Requires parallelization = 2 (PEXEC). Sets number of cpu cores to use"),
     )
     max_iterations = traits.List(
         traits.Int,
@@ -236,7 +231,7 @@ class buildtemplateparallelInputSpec(ANTSCommandInputSpec):
         ),
     )
     bias_field_correction = traits.Bool(
-        argstr="-n 1", desc=("Applies bias field correction to moving " "image")
+        argstr="-n 1", desc=("Applies bias field correction to moving image")
     )
     rigid_body_registration = traits.Bool(
         argstr="-r 1",
@@ -335,7 +330,7 @@ class buildtemplateparallel(ANTSCommand):
             else:
                 start = ""
             return start + " ".join(name for name in val)
-        return super(buildtemplateparallel, self)._format_arg(opt, spec, val)
+        return super()._format_arg(opt, spec, val)
 
     def _list_outputs(self):
         outputs = self._outputs().get()
@@ -366,7 +361,7 @@ class buildtemplateparallel(ANTSCommand):
         outputs["subject_outfiles"] = []
         for filename in self.inputs.in_files:
             _, base, _ = split_filename(filename)
-            temp = glob(os.path.realpath("%s%s*" % (self.inputs.out_prefix, base)))
+            temp = glob(os.path.realpath(f"{self.inputs.out_prefix}{base}*"))
             for file_ in temp:
                 outputs["subject_outfiles"].append(file_)
         return outputs
