@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
@@ -17,6 +16,7 @@ from dateutil.parser import parse as parseutc
 import platform
 
 from ... import logging, config
+from ...utils.datetime import utcnow
 from ...utils.misc import is_container, rgetcwd
 from ...utils.filemanip import md5, hash_infile
 
@@ -28,7 +28,7 @@ HELP_LINEWIDTH = 70
 class RuntimeContext(AbstractContextManager):
     """A context manager to run NiPype interfaces."""
 
-    __slots__ = ("_runtime", "_resmon", "_ignore_exc")
+    __slots__ = ("_ignore_exc", "_resmon", "_runtime")
 
     def __init__(self, resource_monitor=False, ignore_exception=False):
         """Initialize the context manager object."""
@@ -73,7 +73,7 @@ class RuntimeContext(AbstractContextManager):
         if self._runtime.redirect_x:
             self._runtime.environ["DISPLAY"] = config.get_display()
 
-        self._runtime.startTime = dt.isoformat(dt.utcnow())
+        self._runtime.startTime = dt.isoformat(utcnow())
         self._resmon.start()
         # TODO: Perhaps clean-up path and ensure it exists?
         os.chdir(self._runtime.cwd)
@@ -81,7 +81,7 @@ class RuntimeContext(AbstractContextManager):
 
     def __exit__(self, exc_type, exc_value, exc_tb):
         """Tear-down interface execution."""
-        self._runtime.endTime = dt.isoformat(dt.utcnow())
+        self._runtime.endTime = dt.isoformat(utcnow())
         timediff = parseutc(self._runtime.endTime) - parseutc(self._runtime.startTime)
         self._runtime.duration = (
             timediff.days * 86400 + timediff.seconds + timediff.microseconds / 1e6
@@ -100,7 +100,7 @@ class RuntimeContext(AbstractContextManager):
                 traceback.format_exception(exc_type, exc_value, exc_tb)
             )
             # Gather up the exception arguments and append nipype info.
-            exc_args = exc_value.args if getattr(exc_value, "args") else tuple()
+            exc_args = exc_value.args or ()
             exc_args += (
                 f"An exception of type {exc_type.__name__} occurred while "
                 f"running interface {self._runtime.interface}.",
@@ -129,10 +129,10 @@ class NipypeInterfaceError(Exception):
         self.value = value
 
     def __str__(self):
-        return "{}".format(self.value)
+        return f"{self.value}"
 
 
-class Bunch(object):
+class Bunch:
     """
     Dictionary-like class that provides attribute-style access to its items.
 
@@ -203,11 +203,11 @@ class Bunch(object):
             if isinstance(v, dict):
                 pairs = []
                 for key, value in sorted(v.items()):
-                    pairs.append("'%s': %s" % (key, value))
+                    pairs.append(f"'{key}': {value}")
                 v = "{" + ", ".join(pairs) + "}"
-                outstr.append("%s=%s" % (k, v))
+                outstr.append(f"{k}={v}")
             else:
-                outstr.append("%s=%r" % (k, v))
+                outstr.append(f"{k}={v!r}")
             first = False
         outstr.append(")")
         return "".join(outstr)
@@ -289,7 +289,7 @@ def _hash_bunch_dict(adict, key):
     return [(afile, hash_infile(afile)) for afile in stuff]
 
 
-class InterfaceResult(object):
+class InterfaceResult:
     """Object that contains the results of running a particular Interface.
 
     Attributes
@@ -448,7 +448,7 @@ def get_trait_desc(inputs, name, spec):
     default = ""
     if spec.usedefault:
         default = ", nipype default value: %s" % str(spec.default_value()[1])
-    line = "(%s%s)" % (type_info, default)
+    line = f"({type_info}{default})"
 
     manhelpstr = wrap(
         line,
@@ -468,7 +468,7 @@ def get_trait_desc(inputs, name, spec):
         pos = spec.position
         if pos is not None:
             manhelpstr += wrap(
-                "argument: ``%s``, position: %s" % (argstr, pos),
+                f"argument: ``{argstr}``, position: {pos}",
                 HELP_LINEWIDTH,
                 initial_indent="\t\t",
                 subsequent_indent="\t\t",
