@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 import os
@@ -117,7 +116,7 @@ def test_BaseInterface_load_save_inputs(tmpdir):
         input_spec = InputSpec
 
         def __init__(self, **inputs):
-            super(DerivedInterface, self).__init__(**inputs)
+            super().__init__(**inputs)
 
     inputs_dict = {"input1": 12, "input3": True, "input4": "some string"}
     bif = DerivedInterface(**inputs_dict)
@@ -288,28 +287,28 @@ def test_unavailable_input():
         _version = "0.6"
 
     has = WithInput()
-    hasnt = WithoutInput()
+    hasnot = WithoutInput()
     trying_anyway = WithoutInput(foo=3)
     assert has.inputs.foo == 3
-    assert not nib.isdefined(hasnt.inputs.foo)
+    assert not nib.isdefined(hasnot.inputs.foo)
     assert trying_anyway.inputs.foo == 3
 
     has.run()
-    hasnt.run()
+    hasnot.run()
     with pytest.raises(Exception):
         trying_anyway.run()
 
     # Still settable
     has.inputs.foo = 4
-    hasnt.inputs.foo = 4
+    hasnot.inputs.foo = 4
     trying_anyway.inputs.foo = 4
     assert has.inputs.foo == 4
-    assert hasnt.inputs.foo == 4
+    assert hasnot.inputs.foo == 4
     assert trying_anyway.inputs.foo == 4
 
     has.run()
     with pytest.raises(Exception):
-        hasnt.run()
+        hasnot.run()
     with pytest.raises(Exception):
         trying_anyway.run()
 
@@ -571,13 +570,13 @@ def test_CommandLine_prefix(tmpdir):
     ci.run()
 
     class OOPShell(nib.CommandLine):
-        _cmd_prefix = "bash {}/".format(oop)
+        _cmd_prefix = f"bash {oop}/"
 
     ci = OOPShell(command=script_name)
     ci.run()
 
     class OOPBadShell(nib.CommandLine):
-        _cmd_prefix = "shell_dne {}/".format(oop)
+        _cmd_prefix = f"shell_dne {oop}/"
 
     ci = OOPBadShell(command=script_name)
     with pytest.raises(IOError):
