@@ -50,7 +50,7 @@ IMG_FORMATS = {
     "nifti2": (".nii", ".nii.gz"),
     "nrrd": (".nrrd", ".nhdr"),
 }
-IMG_ZIP_FMT = set([".nii.gz", "tar.gz", ".gii.gz", ".mgz", ".mgh.gz", "img.gz"])
+IMG_ZIP_FMT = {".nii.gz", "tar.gz", ".gii.gz", ".mgz", ".mgh.gz", "img.gz"}
 
 """
 The functions that pop-up the Traits GUIs, edit_traits and
@@ -58,7 +58,7 @@ configure_traits, were failing because all of our inputs default to
 Undefined deep and down in traits/ui/wx/list_editor.py it checks for
 the len() of the elements of the list.  The _Undefined class in traits
 does not define the __len__ method and would error.  I tried defining
-our own Undefined and even sublassing Undefined, but both of those
+our own Undefined and even subclassing Undefined, but both of those
 failed with a TraitError in our initializer when we assign the
 Undefined to the inputs because of an incompatible type:
 
@@ -121,7 +121,7 @@ class BasePath(TraitType):
         """Create a BasePath trait."""
         self.exists = exists
         self.resolve = resolve
-        super(BasePath, self).__init__(value, **metadata)
+        super().__init__(value, **metadata)
 
     def validate(self, objekt, name, value, return_pathlike=False):
         """Validate a value change."""
@@ -298,7 +298,7 @@ class File(BasePath):
         resolve=False,
         allow_compressed=True,
         extensions=None,
-        **metadata
+        **metadata,
     ):
         """Create a File trait."""
         if extensions is not None:
@@ -309,28 +309,23 @@ class File(BasePath):
                 extensions = list(set(extensions) - IMG_ZIP_FMT)
 
             self._exts = sorted(
-                set(
-                    [
-                        ".%s" % ext if not ext.startswith(".") else ext
-                        for ext in extensions
-                    ]
-                )
+                {f".{ext}" if not ext.startswith(".") else ext for ext in extensions}
             )
 
-        super(File, self).__init__(
+        super().__init__(
             value=value,
             exists=exists,
             resolve=resolve,
             extensions=self._exts,
-            **metadata
+            **metadata,
         )
 
     def validate(self, objekt, name, value, return_pathlike=False):
         """Validate a value change."""
-        value = super(File, self).validate(objekt, name, value, return_pathlike=True)
+        value = super().validate(objekt, name, value, return_pathlike=True)
         if self._exts:
             fname = value.name
-            if not any((fname.endswith(e) for e in self._exts)):
+            if not any(fname.endswith(e) for e in self._exts):
                 self.error(objekt, name, str(value))
 
         if not return_pathlike:
@@ -348,7 +343,7 @@ class ImageFile(File):
         exists=False,
         resolve=False,
         types=None,
-        **metadata
+        **metadata,
     ):
         """Create an ImageFile trait."""
         extensions = None
@@ -366,15 +361,23 @@ Unknown value(s) %s for metadata type of an ImageFile input.\
                 )
             extensions = [ext for t in types for ext in IMG_FORMATS[t]]
 
-        super(ImageFile, self).__init__(
+        super().__init__(
             value=value,
             exists=exists,
             extensions=extensions,
             resolve=resolve,
-            **metadata
+            **metadata,
         )
 
 
+class Tuple(traits.BaseTuple):
+    def validate(self, objekt, name, value):
+        if isinstance(value, list):
+            value = tuple(value)
+
+        return super().validate(objekt, name, value)
+
+
 def isdefined(objekt):
     return not isinstance(objekt, _Undefined)
 
@@ -421,7 +424,7 @@ class MultiObject(traits.List):
             and not isinstance(value[0], list)
         ):
             newvalue = [value]
-        value = super(MultiObject, self).validate(objekt, name, newvalue)
+        value = super().validate(objekt, name, newvalue)
 
         if value:
             return value
@@ -560,12 +563,10 @@ def _recurse_on_path_traits(func, thistrait, value, cwd):
             k: _recurse_on_path_traits(func, innertrait, v, cwd)
             for k, v in value.items()
         }
-    elif isinstance(value, tuple) and thistrait.is_trait_type(traits.Tuple):
+    elif isinstance(value, tuple) and thistrait.is_trait_type(traits.BaseTuple):
         value = tuple(
-            [
-                _recurse_on_path_traits(func, subtrait, v, cwd)
-                for subtrait, v in zip(thistrait.handler.types, value)
-            ]
+            _recurse_on_path_traits(func, subtrait, v, cwd)
+            for subtrait, v in zip(thistrait.handler.types, value)
         )
     elif thistrait.is_trait_type(traits.TraitCompound):
         is_str = [
