@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 import os
 
 from ...utils.filemanip import split_filename
@@ -45,7 +43,7 @@ class SFPICOCalibDataInputSpec(StdOutCommandLineInputSpec):
         minlen=2,
         maxlen=2,
         units="NA",
-        desc=("Minimum and maximum FA for the single tensor " "synthetic data."),
+        desc=("Minimum and maximum FA for the single tensor synthetic data."),
     )
     onedtfastep = traits.Float(
         argstr="-onedtfastep %f",
@@ -82,7 +80,7 @@ class SFPICOCalibDataInputSpec(StdOutCommandLineInputSpec):
         minlen=2,
         maxlen=2,
         units="NA",
-        desc=("Minimum and maximum crossing angles " "between the two fibres."),
+        desc=("Minimum and maximum crossing angles between the two fibres."),
     )
     twodtanglestep = traits.Float(
         argstr="-twodtanglestep %f",
