@@ -5,6 +5,7 @@ from nipype.interfaces.base import (
     InputMultiPath,
     TraitedSpec,
     traits,
+    Tuple,
     isdefined,
     File,
     Str,
@@ -184,7 +185,7 @@ class CAT12SegmentInputSpec(SPMCommandInputSpec):
         "Values:\nOptimal: [1.0 0.1]\nFixed 1.0 mm: [1.0 0.1];\nFixed 0.8 mm:[0.8 0.1]"
         "\nBest native: [0.5 0.1]"
     )
-    internal_resampling_process = traits.Tuple(
+    internal_resampling_process = Tuple(
         traits.Float(1),
         traits.Float(0.1),
         minlen=2,
@@ -409,7 +410,7 @@ class CAT12SegmentInputSpec(SPMCommandInputSpec):
         "\nValues: No:[0 0];\nImage->Template (forward): [1 0];\nTemplate->Image (inverse): [0 1]; "
         "\ninverse + forward: [1 1]"
     )
-    warps = traits.Tuple(
+    warps = Tuple(
         traits.Int(1),
         traits.Int(0),
         minlen=2,
@@ -525,7 +526,7 @@ class CAT12Segment(SPMCommand):
         elif opt in ["tpm", "shooting_tpm"]:
             return Cell2Str(val)
 
-        return super(CAT12Segment, self)._format_arg(opt, spec, val)
+        return super()._format_arg(opt, spec, val)
 
     def _list_outputs(self):
         outputs = self._outputs().get()
@@ -575,7 +576,7 @@ class CAT12Segment(SPMCommand):
         ]
 
         outputs["report"] = fname_presuffix(
-            f, prefix=os.path.join("report", f"cat_"), suffix=".xml", use_ext=False
+            f, prefix=os.path.join("report", "cat_"), suffix=".xml", use_ext=False
         )
 
         outputs["label_files"] = [
@@ -726,7 +727,7 @@ class CAT12SANLMDenoising(SPMCommand):
         if opt == "spm_type":
             type_map = {"same": 0, "uint8": 2, "uint16": 512, "float32": 16}
             val = type_map[val]
-        return super(CAT12SANLMDenoising, self)._format_arg(opt, spec, val)
+        return super()._format_arg(opt, spec, val)
 
     def _list_outputs(self):
         outputs = self._outputs().get()
