@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 import os.path as op
@@ -19,7 +18,6 @@ from ..base import (
     OutputMultiPath,
     isdefined,
 )
-from .base import have_cmp
 
 iflogger = logging.getLogger("nipype.interface")
 
@@ -125,7 +123,7 @@ def average_networks(in_files, ntwk_res_file, group_id):
         ntwk = remove_all_edges(ntwk_res_file)
         counting_ntwk = ntwk.copy()
         # Sums all the relevant variables
-        for index, subject in enumerate(in_files):
+        for subject in in_files:
             tmp = _read_pickle(subject)
             iflogger.info("File %s has %i edges", subject, tmp.number_of_edges())
             edges = list(tmp.edges())
@@ -167,8 +165,8 @@ def average_networks(in_files, ntwk_res_file, group_id):
         for edge in edges:
             data = ntwk.edge[edge[0]][edge[1]]
             if ntwk.edge[edge[0]][edge[1]]["count"] >= count_to_keep_edge:
-                for key in list(data.keys()):
-                    if not key == "count":
+                for key in data:
+                    if key != "count":
                         data[key] = data[key] / len(in_files)
                 ntwk.edge[edge[0]][edge[1]] = data
                 avg_ntwk.add_edge(edge[0], edge[1], **data)
@@ -184,8 +182,8 @@ def average_networks(in_files, ntwk_res_file, group_id):
         avg_edges = avg_ntwk.edges()
         for edge in avg_edges:
             data = avg_ntwk.edge[edge[0]][edge[1]]
-            for key in list(data.keys()):
-                if not key == "count":
+            for key in data:
+                if key != "count":
                     edge_dict[key] = np.zeros(
                         (avg_ntwk.number_of_nodes(), avg_ntwk.number_of_nodes())
                     )
@@ -343,7 +341,7 @@ def add_node_data(node_array, ntwk):
     node_ntwk = nx.Graph()
     newdata = {}
     for idx, data in ntwk.nodes(data=True):
-        if not int(idx) == 0:
+        if int(idx) != 0:
             newdata["value"] = node_array[int(idx) - 1]
             data.update(newdata)
             node_ntwk.add_node(int(idx), **data)
@@ -354,8 +352,8 @@ def add_edge_data(edge_array, ntwk, above=0, below=0):
     edge_ntwk = ntwk.copy()
     data = {}
     for x, row in enumerate(edge_array):
-        for y in range(0, np.max(np.shape(edge_array[x]))):
-            if not edge_array[x, y] == 0:
+        for y in range(np.max(np.shape(edge_array[x]))):
+            if edge_array[x, y] != 0:
                 data["value"] = edge_array[x, y]
                 if data["value"] <= below or data["value"] >= above:
                     if edge_ntwk.has_edge(x + 1, y + 1):
@@ -542,8 +540,8 @@ class NetworkXMetrics(BaseInterface):
             "Saving extra measure file to %s in Pickle format",
             op.abspath(out_pickled_extra_measures),
         )
-        with open(out_pickled_extra_measures, "w") as fo:
-            pickle.dump(dict_measures, fo)
+        with open(out_pickled_extra_measures, "w") as f:
+            pickle.dump(dict_measures, f)
 
         iflogger.info("Saving MATLAB measures as %s", matlab)
 
