@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Provides interfaces to various commands provided by diffusion toolkit
@@ -98,7 +97,7 @@ class DTIRecon(CommandLine):
     def _create_gradient_matrix(self, bvecs_file, bvals_file):
         _gradient_matrix_file = "gradient_matrix.txt"
         with open(bvals_file) as fbvals:
-            bvals = [val for val in re.split(r"\s+", fbvals.readline().strip())]
+            bvals = fbvals.readline().strip().split()
         with open(bvecs_file) as fbvecs:
             bvecs_x = fbvecs.readline().split()
             bvecs_y = fbvecs.readline().split()
@@ -107,15 +106,15 @@ class DTIRecon(CommandLine):
         with open(_gradient_matrix_file, "w") as gradient_matrix_f:
             for i in range(len(bvals)):
                 gradient_matrix_f.write(
-                    "%s, %s, %s, %s\n" % (bvecs_x[i], bvecs_y[i], bvecs_z[i], bvals[i])
+                    f"{bvecs_x[i]}, {bvecs_y[i]}, {bvecs_z[i]}, {bvals[i]}\n"
                 )
         return _gradient_matrix_file
 
     def _format_arg(self, name, spec, value):
         if name == "bvecs":
             new_val = self._create_gradient_matrix(self.inputs.bvecs, self.inputs.bvals)
-            return super(DTIRecon, self)._format_arg("bvecs", spec, new_val)
-        return super(DTIRecon, self)._format_arg(name, spec, value)
+            return super()._format_arg("bvecs", spec, new_val)
+        return super()._format_arg(name, spec, value)
 
     def _list_outputs(self):
         out_prefix = self.inputs.out_prefix
@@ -208,7 +207,7 @@ and 0.1 for other methods""",
         desc="set angle threshold. default value is 35 degree", argstr="-at %f"
     )
     angle_threshold_weight = traits.Float(
-        desc="set angle threshold weighting factor. weighting will be be applied "
+        desc="set angle threshold weighting factor. weighting will be applied "
         "on top of the angle_threshold",
         argstr="-atw %f",
     )
@@ -277,7 +276,7 @@ class DTITracker(CommandLine):
             copy=False,
         )
 
-        return super(DTITracker, self)._run_interface(runtime)
+        return super()._run_interface(runtime)
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
