@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """The freesurfer module provides basic functions for interfacing with
@@ -12,6 +11,7 @@ from ..base import (
     TraitedSpec,
     File,
     traits,
+    Tuple,
     InputMultiPath,
     OutputMultiPath,
     Directory,
@@ -73,7 +73,7 @@ class MRISPreprocInputSpec(FSTraitedSpec):
         argstr="--surfdir %s", desc="alternative directory (instead of surf)"
     )
     vol_measure_file = InputMultiPath(
-        traits.Tuple(File(exists=True), File(exists=True)),
+        Tuple(File(exists=True), File(exists=True)),
         argstr="--iv %s %s...",
         desc="list of volume measure and reg file tuples",
     )
@@ -137,7 +137,7 @@ class MRISPreproc(FSCommand):
         outputs["out_file"] = outfile
         if not isdefined(outfile):
             outputs["out_file"] = os.path.join(
-                os.getcwd(), "concat_%s_%s.mgz" % (self.inputs.hemi, self.inputs.target)
+                os.getcwd(), f"concat_{self.inputs.hemi}_{self.inputs.target}.mgz"
             )
         return outputs
 
@@ -231,7 +231,7 @@ class MRISPreprocReconAll(MRISPreproc):
             if isdefined(self.inputs.surf_measure_file):
                 copy2subjdir(self, self.inputs.surf_measure_file, folder)
 
-        return super(MRISPreprocReconAll, self).run(**inputs)
+        return super().run(**inputs)
 
     def _format_arg(self, name, spec, value):
         # mris_preproc looks for these files in the surf dir
@@ -241,7 +241,7 @@ class MRISPreprocReconAll(MRISPreproc):
         if name == "surf_measure_file":
             basename = os.path.basename(value)
             return spec.argstr % basename.lstrip("rh.").lstrip("lh.")
-        return super(MRISPreprocReconAll, self)._format_arg(name, spec, value)
+        return super()._format_arg(name, spec, value)
 
 
 class GLMFitInputSpec(FSTraitedSpec):
@@ -250,7 +250,7 @@ class GLMFitInputSpec(FSTraitedSpec):
         desc="input 4D file", argstr="--y %s", mandatory=True, copyfile=False
     )
     _design_xor = ("fsgd", "design", "one_sample")
-    fsgd = traits.Tuple(
+    fsgd = Tuple(
         File(exists=True),
         traits.Enum("doss", "dods"),
         argstr="--fsgd %s %s",
@@ -275,7 +275,7 @@ class GLMFitInputSpec(FSTraitedSpec):
     per_voxel_reg = InputMultiPath(
         File(exists=True), argstr="--pvr %s...", desc="per-voxel regressors"
     )
-    self_reg = traits.Tuple(
+    self_reg = Tuple(
         traits.Int,
         traits.Int,
         traits.Int,
@@ -366,7 +366,7 @@ class GLMFitInputSpec(FSTraitedSpec):
     surf_geo = traits.Str(
         "white", usedefault=True, desc="surface geometry name (e.g. white, pial)"
     )
-    simulation = traits.Tuple(
+    simulation = Tuple(
         traits.Enum("perm", "mc-full", "mc-z"),
         traits.Int(min=1),
         traits.Float,
@@ -377,7 +377,7 @@ class GLMFitInputSpec(FSTraitedSpec):
     sim_sign = traits.Enum(
         "abs", "pos", "neg", argstr="--sim-sign %s", desc="abs, pos, or neg"
     )
-    uniform = traits.Tuple(
+    uniform = Tuple(
         traits.Float,
         traits.Float,
         argstr="--uniform %f %f",
@@ -390,7 +390,7 @@ class GLMFitInputSpec(FSTraitedSpec):
     save_cond = traits.Bool(
         argstr="--save-cond", desc="flag to save design matrix condition at each voxel"
     )
-    vox_dump = traits.Tuple(
+    vox_dump = Tuple(
         traits.Int,
         traits.Int,
         traits.Int,
@@ -401,26 +401,34 @@ class GLMFitInputSpec(FSTraitedSpec):
     synth = traits.Bool(argstr="--synth", desc="replace input with gaussian")
     resynth_test = traits.Int(argstr="--resynthtest %d", desc="test GLM by resynthsis")
     profile = traits.Int(argstr="--profile %d", desc="niters : test speed")
-    mrtm1 = traits.Tuple(
+    mrtm1 = Tuple(
         File(exists=True),
         File(exists=True),
         argstr="--mrtm1 %s %s",
         desc="RefTac TimeSec : perform MRTM1 kinetic modeling",
     )
-    mrtm2 = traits.Tuple(
+    mrtm2 = Tuple(
         File(exists=True),
         File(exists=True),
         traits.Float,
         argstr="--mrtm2 %s %s %f",
         desc="RefTac TimeSec k2prime : perform MRTM2 kinetic modeling",
     )
-    logan = traits.Tuple(
+    logan = Tuple(
         File(exists=True),
         File(exists=True),
         traits.Float,
         argstr="--logan %s %s %f",
         desc="RefTac TimeSec tstar   : perform Logan kinetic modeling",
     )
+    bp_clip_neg = traits.Bool(
+        argstr="--bp-clip-neg",
+        desc="set negative BP voxels to zero",
+    )
+    bp_clip_max = traits.Float(
+        argstr="--bp-clip-max %f",
+        desc="set BP voxels above max to max",
+    )
     force_perm = traits.Bool(
         argstr="--perm-force",
         desc="force perumtation test, even when design matrix is not orthog",
@@ -491,7 +499,7 @@ class GLMFit(FSCommand):
         if name == "surf":
             _si = self.inputs
             return spec.argstr % (_si.subject_id, _si.hemi, _si.surf_geo)
-        return super(GLMFit, self)._format_arg(name, spec, value)
+        return super()._format_arg(name, spec, value)
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
@@ -565,7 +573,7 @@ class GLMFit(FSCommand):
 
 class OneSampleTTest(GLMFit):
     def __init__(self, **kwargs):
-        super(OneSampleTTest, self).__init__(**kwargs)
+        super().__init__(**kwargs)
         self.inputs.one_sample = True
 
 
@@ -666,7 +674,7 @@ class Binarize(FSCommand):
                 outfile = fname_presuffix(
                     self.inputs.in_file,
                     newpath=os.getcwd(),
-                    suffix=".".join(("_thresh", self.inputs.out_type)),
+                    suffix=f"_thresh.{self.inputs.out_type}",
                     use_ext=False,
                 )
             else:
@@ -697,7 +705,7 @@ class Binarize(FSCommand):
             return spec.argstr % fname
         if name == "out_type":
             return ""
-        return super(Binarize, self)._format_arg(name, spec, value)
+        return super()._format_arg(name, spec, value)
 
     def _gen_filename(self, name):
         if name == "binary_file":
@@ -826,7 +834,7 @@ class SegStatsInputSpec(FSTraitedSpec):
         mandatory=True,
         desc="segmentation volume path",
     )
-    annot = traits.Tuple(
+    annot = Tuple(
         traits.Str,
         traits.Enum("lh", "rh"),
         traits.Str,
@@ -835,7 +843,7 @@ class SegStatsInputSpec(FSTraitedSpec):
         mandatory=True,
         desc="subject hemi parc : use surface parcellation",
     )
-    surf_label = traits.Tuple(
+    surf_label = Tuple(
         traits.Str,
         traits.Enum("lh", "rh"),
         traits.Str,
@@ -1066,7 +1074,7 @@ class SegStats(FSCommand):
                 ".mgz", ""
             )
             return spec.argstr % (value, intensity_name)
-        return super(SegStats, self)._format_arg(name, spec, value)
+        return super()._format_arg(name, spec, value)
 
     def _gen_filename(self, name):
         if name == "summary_file":
@@ -1158,7 +1166,7 @@ class SegStatsReconAll(SegStats):
     def _format_arg(self, name, spec, value):
         if name == "brainmask_file":
             return spec.argstr % os.path.basename(value)
-        return super(SegStatsReconAll, self)._format_arg(name, spec, value)
+        return super()._format_arg(name, spec, value)
 
     def run(self, **inputs):
         if self.inputs.copy_inputs:
@@ -1182,7 +1190,7 @@ class SegStatsReconAll(SegStats):
             )
             copy2subjdir(self, self.inputs.in_intensity, "mri")
             copy2subjdir(self, self.inputs.brainmask_file, "mri")
-        return super(SegStatsReconAll, self).run(**inputs)
+        return super().run(**inputs)
 
 
 class Label2VolInputSpec(FSTraitedSpec):
@@ -1244,7 +1252,7 @@ class Label2VolInputSpec(FSTraitedSpec):
     label_voxel_volume = traits.Float(
         argstr="--labvoxvol %f", desc="volume of each label point (def 1mm3)"
     )
-    proj = traits.Tuple(
+    proj = Tuple(
         traits.Enum("abs", "frac"),
         traits.Float,
         traits.Float,
@@ -1333,7 +1341,7 @@ class MS_LDAInputSpec(FSTraitedSpec):
         exists=False,
         argstr="-synth %s",
         mandatory=True,
-        desc=("filename for the synthesized output " "volume"),
+        desc=("filename for the synthesized output volume"),
     )
     label_file = File(
         exists=True, argstr="-label %s", desc="filename of the label volume"
@@ -1346,10 +1354,10 @@ class MS_LDAInputSpec(FSTraitedSpec):
     )
     conform = traits.Bool(
         argstr="-conform",
-        desc=("Conform the input volumes (brain mask " "typically already conformed)"),
+        desc=("Conform the input volumes (brain mask typically already conformed)"),
     )
     use_weights = traits.Bool(
-        argstr="-W", desc=("Use the weights from a previously " "generated weight file")
+        argstr="-W", desc=("Use the weights from a previously generated weight file")
     )
     images = InputMultiPath(
         File(exists=True),
@@ -1411,7 +1419,7 @@ class MS_LDA(FSCommand):
             else:
                 return ""
                 # TODO: Fix bug when boolean values are set explicitly to false
-        return super(MS_LDA, self)._format_arg(name, spec, value)
+        return super()._format_arg(name, spec, value)
 
     def _gen_filename(self, name):
         pass
@@ -1461,9 +1469,8 @@ class Label2LabelInputSpec(FSTraitedSpec):
         desc="Registration method",
     )
     copy_inputs = traits.Bool(
-        desc="If running as a node, set this to True."
-        + "This will copy the input files to the node "
-        + "directory."
+        desc="If running as a node, set this to True. "
+        "This will copy the input files to the node directory."
     )
 
 
@@ -1519,22 +1526,20 @@ class Label2Label(FSCommand):
             if "subjects_dir" in inputs:
                 inputs["subjects_dir"] = self.inputs.subjects_dir
             hemi = self.inputs.hemisphere
-            copy2subjdir(
-                self, self.inputs.sphere_reg, "surf", "{0}.sphere.reg".format(hemi)
-            )
-            copy2subjdir(self, self.inputs.white, "surf", "{0}.white".format(hemi))
+            copy2subjdir(self, self.inputs.sphere_reg, "surf", f"{hemi}.sphere.reg")
+            copy2subjdir(self, self.inputs.white, "surf", f"{hemi}.white")
             copy2subjdir(
                 self,
                 self.inputs.source_sphere_reg,
                 "surf",
-                "{0}.sphere.reg".format(hemi),
+                f"{hemi}.sphere.reg",
                 subject_id=self.inputs.source_subject,
             )
             copy2subjdir(
                 self,
                 self.inputs.source_white,
                 "surf",
-                "{0}.white".format(hemi),
+                f"{hemi}.white",
                 subject_id=self.inputs.source_subject,
             )
 
@@ -1545,7 +1550,7 @@ class Label2Label(FSCommand):
         if not os.path.isdir(label_dir):
             os.makedirs(label_dir)
 
-        return super(Label2Label, self).run(**inputs)
+        return super().run(**inputs)
 
 
 class Label2AnnotInputSpec(FSTraitedSpec):
@@ -1618,7 +1623,7 @@ class Label2Annot(FSCommand):
                 self,
                 self.inputs.orig,
                 folder="surf",
-                basename="{0}.orig".format(self.inputs.hemisphere),
+                basename=f"{self.inputs.hemisphere}.orig",
             )
         # label dir must exist in order for output file to be written
         label_dir = os.path.join(
@@ -1626,7 +1631,7 @@ class Label2Annot(FSCommand):
         )
         if not os.path.isdir(label_dir):
             os.makedirs(label_dir)
-        return super(Label2Annot, self).run(**inputs)
+        return super().run(**inputs)
 
     def _list_outputs(self):
         outputs = self._outputs().get()
@@ -1716,7 +1721,7 @@ class SphericalAverage(FSCommand):
             for item in ["lh.", "rh."]:
                 surf = surf.replace(item, "")
             return spec.argstr % surf
-        return super(SphericalAverage, self)._format_arg(name, spec, value)
+        return super()._format_arg(name, spec, value)
 
     def _gen_filename(self, name):
         if name == "in_average":
