@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Provides interfaces to various commands for running PET analyses provided by FreeSurfer
@@ -11,6 +10,7 @@ from ..base import (
     TraitedSpec,
     File,
     traits,
+    Tuple,
     Directory,
     InputMultiPath,
     isdefined,
@@ -60,7 +60,7 @@ class GTMSegInputSpec(FSTraitedSpec):
         desc="distance threshold to use when subsegmenting WM (default is 5)",
     )
 
-    ctx_annot = traits.Tuple(
+    ctx_annot = Tuple(
         traits.String,
         traits.Int,
         traits.Int,
@@ -68,7 +68,7 @@ class GTMSegInputSpec(FSTraitedSpec):
         desc="annot lhbase rhbase : annotation to use for cortical segmentation (default is aparc 1000 2000)",
     )
 
-    wm_annot = traits.Tuple(
+    wm_annot = Tuple(
         traits.String,
         traits.Int,
         traits.Int,
@@ -187,7 +187,7 @@ class GTMPVCInputSpec(FSTraitedSpec):
         desc="ignore areas outside of the mask (in input vol space)",
     )
 
-    auto_mask = traits.Tuple(
+    auto_mask = Tuple(
         traits.Float,
         traits.Float,
         argstr="--auto-mask %f %f",
@@ -224,7 +224,7 @@ class GTMPVCInputSpec(FSTraitedSpec):
         argstr="--tt-reduce", desc="reduce segmentation to that of a tissue type"
     )
 
-    replace = traits.Tuple(
+    replace = Tuple(
         traits.Int,
         traits.Int,
         argstr="--replace %i %i",
@@ -293,7 +293,7 @@ class GTMPVCInputSpec(FSTraitedSpec):
         desc="voxsize : set RBV voxel resolution (good for when standard res takes too much memory)",
     )
 
-    mg = traits.Tuple(
+    mg = Tuple(
         traits.Float,
         traits.List(traits.String),
         argstr="--mg %g %s",
@@ -324,7 +324,7 @@ class GTMPVCInputSpec(FSTraitedSpec):
         desc="RefId1 RefId2 ... : compute HiBinding TAC for KM as mean of given RefIds",
     )
 
-    steady_state_params = traits.Tuple(
+    steady_state_params = Tuple(
         traits.Float,
         traits.Float,
         traits.Float,
@@ -359,7 +359,7 @@ class GTMPVCInputSpec(FSTraitedSpec):
         desc="save signal estimate (yhat) smoothed with the PSF",
     )
 
-    save_yhat_with_noise = traits.Tuple(
+    save_yhat_with_noise = Tuple(
         traits.Int,
         traits.Int,
         argstr="--save-yhat-with-noise %i %i",
@@ -386,7 +386,7 @@ class GTMPVCInputSpec(FSTraitedSpec):
         desc="opt : optimization schema for applying adaptive GTM",
     )
 
-    opt_tol = traits.Tuple(
+    opt_tol = Tuple(
         traits.Int,
         traits.Float,
         traits.Float,
@@ -459,10 +459,25 @@ class GTMPVCOutputSpec(TraitedSpec):
     yhat_with_noise = File(
         desc="4D PET file with full FOV of signal estimate (yhat) with noise after PVC (smoothed with PSF)",
     )
+    eres = File(
+        desc="4D PET file of residual error after PVC (smoothed with PSF)",
+    )
+    tissue_fraction = File(
+        desc="4D PET file of tissue fraction before PVC",
+    )
+    tissue_fraction_psf = File(
+        desc="4D PET file of tissue fraction after PVC (smoothed with PSF)",
+    )
+    seg = File(
+        desc="Segmentation file of regions used for PVC",
+    )
+    seg_ctab = File(
+        desc="Color table file for segmentation file",
+    )
 
 
 class GTMPVC(FSCommand):
-    """create an anatomical segmentation for the geometric transfer matrix (GTM).
+    """Perform Partial Volume Correction (PVC) to PET Data.
 
     Examples
     --------
@@ -517,7 +532,7 @@ class GTMPVC(FSCommand):
             )
         if name == 'mg':
             return spec.argstr % (val[0], ' '.join(val[1]))
-        return super(GTMPVC, self)._format_arg(name, spec, val)
+        return super()._format_arg(name, spec, val)
 
     def _list_outputs(self):
         outputs = self.output_spec().get()
@@ -537,6 +552,15 @@ class GTMPVC(FSCommand):
         outputs["gtm_stats"] = os.path.join(pvcdir, "gtm.stats.dat")
         outputs["reg_pet2anat"] = os.path.join(pvcdir, "aux", "bbpet2anat.lta")
         outputs["reg_anat2pet"] = os.path.join(pvcdir, "aux", "anat2bbpet.lta")
+        outputs["eres"] = os.path.join(pvcdir, "eres.nii.gz")
+        outputs["tissue_fraction"] = os.path.join(
+            pvcdir, "aux", "tissue.fraction.nii.gz"
+        )
+        outputs["tissue_fraction_psf"] = os.path.join(
+            pvcdir, "aux", "tissue.fraction.psf.nii.gz"
+        )
+        outputs["seg"] = os.path.join(pvcdir, "aux", "seg.nii.gz")
+        outputs["seg_ctab"] = os.path.join(pvcdir, "aux", "seg.ctab")
 
         # Assign the conditional outputs
         if self.inputs.save_input:
@@ -557,14 +581,14 @@ class GTMPVC(FSCommand):
             outputs["rbv"] = os.path.join(pvcdir, "rbv.nii.gz")
             outputs["reg_rbvpet2anat"] = os.path.join(pvcdir, "aux", "rbv2anat.lta")
             outputs["reg_anat2rbvpet"] = os.path.join(pvcdir, "aux", "anat2rbv.lta")
-        if self.inputs.opt:
+        if self.inputs.optimization_schema:
             outputs["opt_params"] = os.path.join(pvcdir, "aux", "opt.params.dat")
 
         return outputs
 
 
-class MRTMInputSpec(GLMFitInputSpec):
-    mrtm1 = traits.Tuple(
+class MRTM1InputSpec(GLMFitInputSpec):
+    mrtm1 = Tuple(
         File(exists=True),
         File(exists=True),
         mandatory=True,
@@ -573,12 +597,12 @@ class MRTMInputSpec(GLMFitInputSpec):
     )
 
 
-class MRTM(GLMFit):
+class MRTM1(GLMFit):
     """Perform MRTM1 kinetic modeling.
 
     Examples
     --------
-    >>> mrtm = MRTM()
+    >>> mrtm = MRTM1()
     >>> mrtm.inputs.in_file = 'tac.nii'
     >>> mrtm.inputs.mrtm1 = ('ref_tac.dat', 'timing.dat')
     >>> mrtm.inputs.glm_dir = 'mrtm'
@@ -586,11 +610,11 @@ class MRTM(GLMFit):
     'mri_glmfit --glmdir mrtm --y tac.nii --mrtm1 ref_tac.dat timing.dat'
     """
 
-    input_spec = MRTMInputSpec
+    input_spec = MRTM1InputSpec
 
 
 class MRTM2InputSpec(GLMFitInputSpec):
-    mrtm2 = traits.Tuple(
+    mrtm2 = Tuple(
         File(exists=True),
         File(exists=True),
         traits.Float,
@@ -615,8 +639,8 @@ class MRTM2(GLMFit):
     input_spec = MRTM2InputSpec
 
 
-class LoganRefInputSpec(GLMFitInputSpec):
-    logan = traits.Tuple(
+class LoganInputSpec(GLMFitInputSpec):
+    logan = Tuple(
         File(exists=True),
         File(exists=True),
         traits.Float,
@@ -626,11 +650,11 @@ class LoganRefInputSpec(GLMFitInputSpec):
     )
 
 
-class LoganRef(GLMFit):
-    """Perform Logan reference kinetic modeling.
+class Logan(GLMFit):
+    """Perform Logan kinetic modeling.
     Examples
     --------
-    >>> logan = LoganRef()
+    >>> logan = Logan()
     >>> logan.inputs.in_file = 'tac.nii'
     >>> logan.inputs.logan = ('ref_tac.dat', 'timing.dat', 2600)
     >>> logan.inputs.glm_dir = 'logan'
@@ -638,4 +662,4 @@ class LoganRef(GLMFit):
     'mri_glmfit --glmdir logan --y tac.nii --logan ref_tac.dat timing.dat 2600'
     """
 
-    input_spec = LoganRefInputSpec
+    input_spec = LoganInputSpec
