@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """The fix module provides classes for interfacing with the `FSL FIX
@@ -106,11 +105,11 @@ class TrainingSetCreator(BaseInterface):
     _always_run = True
 
     def _run_interface(self, runtime):
-        mel_icas = []
-        for item in self.inputs.mel_icas_in:
-            if os.path.exists(os.path.join(item, "hand_labels_noise.txt")):
-                mel_icas.append(item)
-
+        mel_icas = [
+            item
+            for item in self.inputs.mel_icas_in
+            if os.path.exists(os.path.join(item, "hand_labels_noise.txt"))
+        ]
         if len(mel_icas) == 0:
             raise Exception(
                 "%s did not find any hand_labels_noise.txt files in the following directories: %s"
@@ -120,10 +119,11 @@ class TrainingSetCreator(BaseInterface):
         return runtime
 
     def _list_outputs(self):
-        mel_icas = []
-        for item in self.inputs.mel_icas_in:
-            if os.path.exists(os.path.join(item, "hand_labels_noise.txt")):
-                mel_icas.append(item)
+        mel_icas = [
+            item
+            for item in self.inputs.mel_icas_in
+            if os.path.exists(os.path.join(item, "hand_labels_noise.txt"))
+        ]
         outputs = self._outputs().get()
         outputs["mel_icas_out"] = mel_icas
         return outputs
@@ -375,7 +375,7 @@ class Cleaner(CommandLine):
 
     def _get_cleaned_functional_filename(self, artifacts_list_filename):
         """extract the proper filename from the first line of the artifacts file"""
-        artifacts_list_file = open(artifacts_list_filename, "r")
+        artifacts_list_file = open(artifacts_list_filename)
         functional_filename, extension = artifacts_list_file.readline().split(".")
         artifacts_list_file_path, artifacts_list_filename = os.path.split(
             artifacts_list_filename
