@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 import os.path as op
@@ -10,7 +9,7 @@ from nibabel.orientations import aff2axcodes
 from ... import logging
 from ...utils.filemanip import split_filename
 from ..base import TraitedSpec, File, isdefined
-from ..dipy.base import DipyBaseInterface, HAVE_DIPY as have_dipy
+from ..dipy.base import DipyBaseInterface
 
 iflogger = logging.getLogger("nipype.interface")
 
@@ -117,9 +116,9 @@ def read_mrtrix_streamlines(in_file, header, as_generator=True):
             pts_str = fileobj.read(n_pts * bytesize)
             nan_str = fileobj.read(bytesize)
             if len(pts_str) < (n_pts * bytesize):
-                if not n_streams == stream_count:
+                if n_streams != stream_count:
                     raise nb.trackvis.HeaderError(
-                        "Expecting %s points, found only %s" % (stream_count, n_streams)
+                        f"Expecting {stream_count} points, found only {n_streams}"
                     )
                     iflogger.error(
                         "Expecting %s points, found only %s", stream_count, n_streams
