@@ -9,8 +9,10 @@ from ..base import (
     CommandLineInputSpec,
     CommandLine,
     traits,
+    Tuple,
     TraitedSpec,
     File,
+    Directory,
     InputMultiPath,
     isdefined,
 )
@@ -224,15 +226,64 @@ class Generate5ttInputSpec(MRTrix3BaseInputSpec):
         "fsl",
         "gif",
         "freesurfer",
+        "hsvs",
         argstr="%s",
         position=-3,
         mandatory=True,
         desc="tissue segmentation algorithm",
     )
-    in_file = File(
-        exists=True, argstr="%s", mandatory=True, position=-2, desc="input image"
+    in_file = traits.Either(
+        File(exists=True),
+        Directory(exists=True),
+        argstr="%s",
+        mandatory=True,
+        position=-2,
+        desc="input image / directory",
     )
     out_file = File(argstr="%s", mandatory=True, position=-1, desc="output image")
+    t2_image = File(
+        exists=True,
+        argstr="-t2 %s",
+        desc="Provide a T2-weighted image in addition to the default T1-weighted image. (Only for 'fsl' algorithm)",
+    )
+    mask_file = File(
+        exists=True,
+        argstr="-mask %s",
+        desc="Provide a brain mask image. (Only for 'fsl' algorithm)",
+    )
+    premasked = traits.Bool(
+        argstr="-premasked",
+        desc="Assume that the input image is already brain-masked. (Only for 'fsl' algorithm)",
+    )
+    nocrop = traits.Bool(
+        argstr="-nocrop",
+        desc="Do not crop the image to the region of interest.",
+    )
+    sgm_amyg_hipp = traits.Bool(
+        argstr="-sgm_amyg_hipp",
+        desc="Include the amygdala and hippocampus in the subcortical grey matter segment.",
+    )
+    template = File(
+        exists=True,
+        argstr="-template %s",
+        desc="Provide an image that will form the template for the generated 5TT image. (Only for 'hsvs' algorithm)",
+    )
+    hippocampi = traits.Enum(
+        "subfields",
+        "first",
+        "aseg",
+        argstr="-hippocampi %s",
+        desc="Choose the method used to segment the hippocampi. (Only for 'freesurfer' algorithm)",
+    )
+    white_stem = traits.Bool(
+        argstr="-white_stem",
+        desc="Classify the brainstem as white matter. (Only for 'hsvs' algorithm)",
+    )
+    lut_file = File(
+        exists=True,
+        argstr="-lut %s",
+        desc="Manually provide path to the lookup table on which the input parcellation image is based. (Only for 'freesurfer' algorithm)",
+    )
 
 
 class Generate5ttOutputSpec(TraitedSpec):
@@ -267,7 +318,7 @@ class Generate5tt(MRTrix3Base):
         return outputs
 
 
-class TensorMetricsInputSpec(CommandLineInputSpec):
+class TensorMetricsInputSpec(MRTrix3BaseInputSpec):
     in_file = File(
         exists=True,
         argstr="%s",
@@ -298,16 +349,14 @@ class TensorMetricsInputSpec(CommandLineInputSpec):
     in_mask = File(
         exists=True,
         argstr="-mask %s",
-        desc=(
-            "only perform computation within the specified binary" " brain mask image"
-        ),
+        desc=("only perform computation within the specified binary brain mask image"),
     )
     modulate = traits.Enum(
         "FA",
         "none",
         "eval",
         argstr="-modulate %s",
-        desc=("how to modulate the magnitude of the" " eigenvectors"),
+        desc=("how to modulate the magnitude of the eigenvectors"),
     )
 
 
@@ -364,7 +413,7 @@ class ComputeTDIInputSpec(CommandLineInputSpec):
     reference = File(
         exists=True,
         argstr="-template %s",
-        desc="a reference" "image to be used as template",
+        desc="a reference image to be used as template",
     )
     vox_size = traits.List(
         traits.Int, argstr="-vox %s", sep=",", desc="voxel dimensions"
@@ -384,7 +433,7 @@ class ComputeTDIInputSpec(CommandLineInputSpec):
     )
     max_tod = traits.Int(
         argstr="-tod %d",
-        desc="generate a Track Orientation " "Distribution (TOD) in each voxel.",
+        desc="generate a Track Orientation Distribution (TOD) in each voxel.",
     )
 
     contrast = traits.Enum(
@@ -396,7 +445,7 @@ class ComputeTDIInputSpec(CommandLineInputSpec):
         "fod_amp",
         "curvature",
         argstr="-constrast %s",
-        desc="define the desired " "form of contrast for the output image",
+        desc="define the desired form of contrast for the output image",
     )
     in_map = File(
         exists=True,
@@ -463,17 +512,17 @@ class ComputeTDIInputSpec(CommandLineInputSpec):
         "(these lengths are then taken into account during TWI calculation)",
     )
     ends_only = traits.Bool(
-        argstr="-ends_only", desc="only map the streamline" " endpoints to the image"
+        argstr="-ends_only", desc="only map the streamline endpoints to the image"
     )
 
     tck_weights = File(
         exists=True,
         argstr="-tck_weights_in %s",
-        desc="specify" " a text scalar file containing the streamline weights",
+        desc="specify a text scalar file containing the streamline weights",
     )
     nthreads = traits.Int(
         argstr="-nthreads %d",
-        desc="number of threads. if zero, the number" " of available cpus will be used",
+        desc="number of threads. if zero, the number of available cpus will be used",
         nohash=True,
     )
 
@@ -570,7 +619,7 @@ class TCK2VTKInputSpec(CommandLineInputSpec):
 
     nthreads = traits.Int(
         argstr="-nthreads %d",
-        desc="number of threads. if zero, the number" " of available cpus will be used",
+        desc="number of threads. if zero, the number of available cpus will be used",
         nohash=True,
     )
 
@@ -824,13 +873,11 @@ class MRTransformInputSpec(MRTrix3BaseInputSpec):
     )
     invert = traits.Bool(
         argstr="-inverse",
-        position=1,
         desc="Invert the specified transform before using it",
     )
     linear_transform = File(
         exists=True,
         argstr="-linear %s",
-        position=1,
         desc=(
             "Specify a linear transform to apply, in the form of a 3x4 or 4x4 ascii file. "
             "Note the standard reverse convention is used, "
@@ -840,38 +887,32 @@ class MRTransformInputSpec(MRTrix3BaseInputSpec):
     )
     replace_transform = traits.Bool(
         argstr="-replace",
-        position=1,
         desc="replace the current transform by that specified, rather than applying it to the current transform",
     )
     transformation_file = File(
         exists=True,
         argstr="-transform %s",
-        position=1,
         desc="The transform to apply, in the form of a 4x4 ascii file.",
     )
     template_image = File(
         exists=True,
         argstr="-template %s",
-        position=1,
         desc="Reslice the input image to match the specified template image.",
     )
     reference_image = File(
         exists=True,
         argstr="-reference %s",
-        position=1,
         desc="in case the transform supplied maps from the input image onto a reference image, use this option to specify the reference. Note that this implicitly sets the -replace option.",
     )
     flip_x = traits.Bool(
         argstr="-flipx",
-        position=1,
         desc="assume the transform is supplied assuming a coordinate system with the x-axis reversed relative to the MRtrix convention (i.e. x increases from right to left). This is required to handle transform matrices produced by FSL's FLIRT command. This is only used in conjunction with the -reference option.",
     )
     quiet = traits.Bool(
         argstr="-quiet",
-        position=1,
         desc="Do not display information messages or progress status.",
     )
-    debug = traits.Bool(argstr="-debug", position=1, desc="Display debugging messages.")
+    debug = traits.Bool(argstr="-debug", desc="Display debugging messages.")
 
 
 class MRTransformOutputSpec(TraitedSpec):
@@ -980,21 +1021,21 @@ class MRResizeInputSpec(MRTrix3BaseInputSpec):
     in_file = File(
         exists=True, argstr="%s", position=-2, mandatory=True, desc="input DWI image"
     )
-    image_size = traits.Tuple(
+    image_size = Tuple(
         (traits.Int, traits.Int, traits.Int),
         argstr="-size %d,%d,%d",
         mandatory=True,
         desc="Number of voxels in each dimension of output image",
         xor=["voxel_size", "scale_factor"],
     )
-    voxel_size = traits.Tuple(
+    voxel_size = Tuple(
         (traits.Float, traits.Float, traits.Float),
         argstr="-voxel %g,%g,%g",
         mandatory=True,
         desc="Desired voxel size in mm for the output image",
         xor=["image_size", "scale_factor"],
     )
-    scale_factor = traits.Tuple(
+    scale_factor = Tuple(
         (traits.Float, traits.Float, traits.Float),
         argstr="-scale %g,%g,%g",
         mandatory=True,
@@ -1188,3 +1229,184 @@ class SH2Amp(CommandLine):
         outputs = self.output_spec().get()
         outputs["out_file"] = op.abspath(self.inputs.out_file)
         return outputs
+
+
+class MaskFilterInputSpec(CommandLineInputSpec):
+    in_file = File(
+        exists=True,
+        mandatory=True,
+        argstr="%s",
+        position=-3,
+        desc="Input mask",
+    )
+    filter = traits.Str(
+        mandatory=True,
+        argstr="%s",
+        position=-2,
+        desc="Filter to perform (e.g. dilate, erode)",
+    )
+    out_file = File(
+        name_source=["input_image"],
+        mandatory=True,
+        argstr="%s",
+        position=-1,
+        desc="Output mask",
+    )
+    npass = traits.Int(argstr="-npass %d", position=1, desc="Number of passes")
+
+
+class MaskFilterOutputSpec(TraitedSpec):
+    out_file = File(exists=True, desc="the filtered output mask")
+
+
+class MaskFilter(CommandLine):
+    """
+    Perform filtering operations on 3D / 4D mask images.
+    Only supports dilate / erode filters at the moment.
+    For more information see: https://mrtrix.readthedocs.io/en/latest/reference/commands/maskfilter.html
+
+
+    Example
+    -------
+
+    >>> import nipype.interfaces.mrtrix3 as mrt
+    >>> mf = mrt.MaskFilter()
+    >>> mf.inputs.in_file = 'mask.mif'
+    >>> mf.inputs.filter = 'dilate'
+    >>> mf.inputs.npass = 2
+    >>> mf.inputs.out_file = 'mask_filtered.mif'
+    >>> mf.cmdline
+    'maskfilter -npass 2 mask.mif dilate mask_filtered.mif'
+    >>> mf.run()                                 # doctest: +SKIP
+    """
+
+    _cmd = "maskfilter"
+    input_spec = MaskFilterInputSpec
+    output_spec = MaskFilterOutputSpec
+
+    def _list_outputs(self):
+        outputs = self.output_spec().get()
+        outputs["out_file"] = op.abspath(self.inputs.out_file)
+        return outputs
+
+
+class MTNormaliseInputSpec(MRTrix3BaseInputSpec):
+    wm_fod = File(
+        argstr="%s",
+        exists=True,
+        position=1,
+        desc="input fod of white matter tissue compartment",
+    )
+    out_file_wm = File(
+        argstr="%s", position=2, desc="output file of white matter tissue compartment"
+    )
+    gm_fod = File(
+        argstr="%s",
+        exists=True,
+        position=3,
+        desc="input fod of grey matter tissue compartment",
+    )
+    out_file_gm = File(
+        argstr="%s", position=4, desc="output file of grey matter tissue compartment"
+    )
+    csf_fod = File(
+        argstr="%s", exists=True, position=5, desc="input fod of CSF tissue compartment"
+    )
+    out_file_csf = File(
+        argstr="%s", position=6, desc="output file of CSF tissue compartment 3"
+    )
+    mask = File(argstr="-mask %s", exists=True, position=-1, desc="input brain mask")
+
+
+class MTNormaliseOutputSpec(TraitedSpec):
+    out_file_wm = File(exists=True, desc="the normalized white matter fod")
+    out_file_gm = File(exists=True, desc="the normalized grey matter fod")
+    out_file_csf = File(exists=True, desc="the normalized csf fod")
+
+
+class MTNormalise(CommandLine):
+    """
+    Multi-tissue informed log-domain intensity normalisation
+
+
+    Example
+    -------
+
+    >>> import nipype.interfaces.mrtrix3 as mrt
+    >>> mtn = mrt.MTNormalise()
+    >>> mtn.inputs.wm_fod = 'wmfod.mif'
+    >>> mtn.inputs.gm_fod = 'gmfod.mif'
+    >>> mtn.inputs.csf_fod = 'csffod.mif'
+    >>> mtn.inputs.out_file_wm = 'wmfod_norm.mif'
+    >>> mtn.inputs.out_file_gm = 'gmfod_norm.mif'
+    >>> mtn.inputs.out_file_csf = 'csffod_norm.mif'
+    >>> mtn.inputs.mask = 'mask.mif'
+    >>> mtn.cmdline
+    'mtnormalise wmfod.mif wmfod_norm.mif gmfod.mif gmfod_norm.mif csffod.mif csffod_norm.mif -mask mask.mif'
+    >>> mtn.run()                                 # doctest: +SKIP
+    """
+
+    _cmd = "mtnormalise"
+    input_spec = MTNormaliseInputSpec
+    output_spec = MTNormaliseOutputSpec
+
+    def _list_outputs(self):
+        outputs = self.output_spec().get()
+        outputs["out_file_wm"] = op.abspath(self.inputs.out_file_wm)
+        outputs["out_file_gm"] = op.abspath(self.inputs.out_file_gm)
+        outputs["out_file_csf"] = op.abspath(self.inputs.out_file_csf)
+        return outputs
+
+
+class Generate5tt2gmwmiInputSpec(MRTrix3BaseInputSpec):
+    in_file = File(
+        exists=True,
+        argstr="%s",
+        mandatory=True,
+        position=-2,
+        desc="the input 5TT segmented anatomical image",
+    )
+    mask_out = File(
+        "mask_gmwmi.mif",
+        argstr="%s",
+        mandatory=True,
+        position=-1,
+        desc="the output mask image",
+    )
+    mask_in = File(
+        argstr="-mask_in %s",
+        position=-3,
+        desc="filter an input mask image according to those voxels that lie upon the grey matter - white matter boundary",
+    )
+
+
+class Generate5tt2gmwmiOutputSpec(TraitedSpec):
+    mask_out = File(exists=True, desc="the output mask file")
+
+
+class Generate5tt2gmwmi(CommandLine):
+    """
+    Generate a mask image appropriate for seeding streamlines on
+    the grey matter-white matter interface
+
+
+    Example
+    -------
+
+    >>> import nipype.interfaces.mrtrix3 as mrt
+    >>> gmwmi = mrt.Generate5tt2gmwmi()
+    >>> gmwmi.inputs.in_file = '5tt_in.mif'
+    >>> gmwmi.inputs.mask_out = 'mask_gmwmi.mif'
+    >>> gmwmi.cmdline
+    '5tt2gmwmi 5tt_in.mif mask_gmwmi.mif'
+    >>> gmwmi.run()                                 # doctest: +SKIP
+    """
+
+    _cmd = "5tt2gmwmi"
+    input_spec = Generate5tt2gmwmiInputSpec
+    output_spec = Generate5tt2gmwmiOutputSpec
+
+    def _list_outputs(self):
+        outputs = self.output_spec().get()
+        outputs["mask_out"] = op.abspath(self.inputs.mask_out)
+        return outputs
