@@ -32,7 +32,7 @@ class NiftyFitCommand(CommandLine):
 
     def __init__(self, **inputs):
         """Init method calling super. No version to be checked."""
-        super(NiftyFitCommand, self).__init__(**inputs)
+        super().__init__(**inputs)
 
     def _gen_fname(self, basename, out_dir=None, suffix=None, ext=None):
         if basename == "":
@@ -45,5 +45,5 @@ class NiftyFitCommand(CommandLine):
         if ext is not None:
             final_ext = ext
         if suffix is not None:
-            final_bn = "".join((final_bn, suffix))
+            final_bn = f"{final_bn}{suffix}"
         return os.path.abspath(os.path.join(out_dir, final_bn + final_ext))
