@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
@@ -9,7 +8,7 @@ The interfaces were written to work with niftyreg version 1.5.10
 """
 import os
 
-from ..base import TraitedSpec, File, traits, isdefined
+from ..base import TraitedSpec, File, traits, Tuple, isdefined
 from .base import get_custom_path, NiftyRegCommand, NiftyRegCommandInputSpec
 from ...utils.filemanip import split_filename
 
@@ -153,12 +152,12 @@ class RegAladin(NiftyRegCommand):
     output_spec = RegAladinOutputSpec
 
     def _list_outputs(self):
-        outputs = super(RegAladin, self)._list_outputs()
+        outputs = super()._list_outputs()
 
         # Make a list of the linear transformation file and the input image
         aff = os.path.abspath(outputs["aff_file"])
         flo = os.path.abspath(self.inputs.flo_file)
-        outputs["avg_output"] = "%s %s" % (aff, flo)
+        outputs["avg_output"] = f"{aff} {flo}"
         return outputs
 
 
@@ -219,22 +218,22 @@ class RegF3DInputSpec(NiftyRegCommandInputSpec):
 
     # Lower threshold for reference image
     desc = "Lower threshold for reference image at the specified time point"
-    rlwth2_thr_val = traits.Tuple(
+    rlwth2_thr_val = Tuple(
         traits.Range(low=0), traits.Float, desc=desc, argstr="-rLwTh %d %f"
     )
     # Upper threshold for reference image
     desc = "Upper threshold for reference image at the specified time point"
-    rupth2_thr_val = traits.Tuple(
+    rupth2_thr_val = Tuple(
         traits.Range(low=0), traits.Float, desc=desc, argstr="-rUpTh %d %f"
     )
     # Lower threshold for reference image
     desc = "Lower threshold for floating image at the specified time point"
-    flwth2_thr_val = traits.Tuple(
+    flwth2_thr_val = Tuple(
         traits.Range(low=0), traits.Float, desc=desc, argstr="-fLwTh %d %f"
     )
     # Upper threshold for reference image
     desc = "Upper threshold for floating image at the specified time point"
-    fupth2_thr_val = traits.Tuple(
+    fupth2_thr_val = Tuple(
         traits.Range(low=0), traits.Float, desc=desc, argstr="-fUpTh %d %f"
     )
 
@@ -264,14 +263,14 @@ only"
     desc = "Number of bins in the histogram for reference image for given \
 time point"
 
-    rbn2_val = traits.Tuple(
+    rbn2_val = Tuple(
         traits.Range(low=0), traits.Range(low=0), desc=desc, argstr="-rbn %d %d"
     )
 
     desc = "Number of bins in the histogram for reference image for given \
 time point"
 
-    fbn2_val = traits.Tuple(
+    fbn2_val = Tuple(
         traits.Range(low=0), traits.Range(low=0), desc=desc, argstr="-fbn %d %d"
     )
 
@@ -279,7 +278,7 @@ time point"
         desc="SD of the Gaussian for computing LNCC", argstr="--lncc %f"
     )
     desc = "SD of the Gaussian for computing LNCC for a given time point"
-    lncc2_val = traits.Tuple(
+    lncc2_val = Tuple(
         traits.Range(low=0), traits.Float, desc=desc, argstr="-lncc %d %f"
     )
 
@@ -386,7 +385,7 @@ class RegF3D(NiftyRegCommand):
         return os.path.join(dn, bn)
 
     def _list_outputs(self):
-        outputs = super(RegF3D, self)._list_outputs()
+        outputs = super()._list_outputs()
 
         if self.inputs.vel_flag is True:
             res_name = self._remove_extension(outputs["res_file"])
@@ -398,7 +397,7 @@ class RegF3D(NiftyRegCommand):
         if self.inputs.vel_flag is True and isdefined(self.inputs.aff_file):
             cpp_file = os.path.abspath(outputs["cpp_file"])
             flo_file = os.path.abspath(self.inputs.flo_file)
-            outputs["avg_output"] = "%s %s %s" % (
+            outputs["avg_output"] = "{} {} {}".format(
                 self.inputs.aff_file,
                 cpp_file,
                 flo_file,
@@ -406,6 +405,6 @@ class RegF3D(NiftyRegCommand):
         else:
             cpp_file = os.path.abspath(outputs["cpp_file"])
             flo_file = os.path.abspath(self.inputs.flo_file)
-            outputs["avg_output"] = "%s %s" % (cpp_file, flo_file)
+            outputs["avg_output"] = f"{cpp_file} {flo_file}"
 
         return outputs
