@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
@@ -28,9 +27,7 @@ class NiftySegCommand(NiftyFitCommand):
     _min_version = None
 
     def __init__(self, **inputs):
-        super(NiftySegCommand, self).__init__(**inputs)
+        super().__init__(**inputs)
 
     def get_version(self):
-        return super(NiftySegCommand, self).version_from_command(
-            cmd="seg_EM", flag="--version"
-        )
+        return super().version_from_command(cmd="seg_EM", flag="--version")
