@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 
@@ -51,7 +50,7 @@ class CalcCoregAffineInputSpec(SPMCommandInputSpec):
         exists=True,
         mandatory=True,
         copyfile=False,
-        desc=("volume transform can be applied to register with " "target"),
+        desc=("volume transform can be applied to register with target"),
     )
     mat = File(desc="Filename used to store affine matrix")
     invmat = File(desc="Filename used to store inverse affine matrix")
@@ -97,7 +96,7 @@ class CalcCoregAffine(SPMCommand):
         """makes name for matfile if doesn exist"""
         pth, mv, _ = split_filename(self.inputs.moving)
         _, tgt, _ = split_filename(self.inputs.target)
-        mat = os.path.join(pth, "%s_to_%s.mat" % (mv, tgt))
+        mat = os.path.join(pth, f"{mv}_to_{tgt}.mat")
         return mat
 
     def _make_matlab_command(self, _):
@@ -107,16 +106,16 @@ class CalcCoregAffine(SPMCommand):
         if not isdefined(self.inputs.invmat):
             self.inputs.invmat = self._make_inv_file()
         script = """
-        target = '%s';
-        moving = '%s';
+        target = '{}';
+        moving = '{}';
         targetv = spm_vol(target);
         movingv = spm_vol(moving);
         x = spm_coreg(targetv, movingv);
         M = spm_matrix(x);
-        save('%s' , 'M' );
+        save('{}' , 'M' );
         M = inv(M);
-        save('%s','M')
-        """ % (
+        save('{}','M')
+        """.format(
             self.inputs.target,
             self.inputs.moving,
             self.inputs.mat,
@@ -168,9 +167,9 @@ class ApplyTransform(SPMCommand):
         outputs = self._list_outputs()
         self.inputs.out_file = outputs["out_file"]
         script = """
-        infile = '%s';
-        outfile = '%s'
-        transform = load('%s');
+        infile = '{}';
+        outfile = '{}'
+        transform = load('{}');
 
         V = spm_vol(infile);
         X = spm_read_vols(V);
@@ -179,7 +178,7 @@ class ApplyTransform(SPMCommand):
         V.fname = fullfile(outfile);
         spm_write_vol(V,X);
 
-        """ % (
+        """.format(
             self.inputs.in_file,
             self.inputs.out_file,
             self.inputs.mat,
@@ -492,13 +491,13 @@ class DicomImport(SPMCommand):
             if val:
                 return 1
             return 0
-        return super(DicomImport, self)._format_arg(opt, spec, val)
+        return super()._format_arg(opt, spec, val)
 
     def _run_interface(self, runtime):
         od = os.path.abspath(self.inputs.output_dir)
         if not os.path.isdir(od):
             os.mkdir(od)
-        return super(DicomImport, self)._run_interface(runtime)
+        return super()._run_interface(runtime)
 
     def _list_outputs(self):
         from glob import glob
