@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Defines functionality for pipelined execution of interfaces
@@ -37,7 +36,6 @@ from ...utils.filemanip import (
 from ...interfaces.base import (
     traits,
     InputMultiPath,
-    CommandLine,
     Undefined,
     DynamicTraitedSpec,
     Bunch,
@@ -174,11 +172,11 @@ class Node(EngineBase):
         """
         # Make sure an interface is set, and that it is an Interface
         if interface is None:
-            raise IOError("Interface must be provided")
+            raise OSError("Interface must be provided")
         if not isinstance(interface, Interface):
-            raise IOError("interface must be an instance of an Interface")
+            raise OSError("interface must be an instance of an Interface")
 
-        super(Node, self).__init__(name, kwargs.get("base_dir"))
+        super().__init__(name, kwargs.get("base_dir"))
 
         self._interface = interface
         self._hierarchy = None
@@ -241,7 +239,7 @@ class Node(EngineBase):
     @needed_outputs.setter
     def needed_outputs(self, new_outputs):
         """Needed outputs changes the hash, refresh if changed"""
-        new_outputs = sorted(list(set(new_outputs or [])))
+        new_outputs = sorted(set(new_outputs or []))
         if new_outputs != self._needed_outputs:
             # Reset hash
             self._hashvalue = None
@@ -653,7 +651,7 @@ Error populating the inputs of node "%s": the results file of the source node \
             logger.debug("Error populating inputs/outputs, (re)aggregating results...")
         except (AttributeError, ImportError) as err:
             logger.debug(
-                "attribute error: %s probably using " "different trait pickled file",
+                "attribute error: %s probably using different trait pickled file",
                 str(err),
             )
             old_inputs = loadpkl(op.join(cwd, "_inputs.pklz"))
@@ -697,7 +695,7 @@ Error populating the inputs of node "%s": the results file of the source node \
             except (FileNotFoundError, AttributeError):
                 # if aggregation does not work, rerun the node
                 logger.info(
-                    "[Node] Some of the outputs were not found: " "rerunning node."
+                    "[Node] Some of the outputs were not found: rerunning node."
                 )
                 copyfiles = False  # OE: this was like this before,
                 execute = True  # I'll keep them for safety
@@ -872,7 +870,7 @@ class JoinNode(Node):
 
         See Node docstring for additional keyword arguments.
         """
-        super(JoinNode, self).__init__(interface, name, **kwargs)
+        super().__init__(interface, name, **kwargs)
 
         self._joinsource = None  # The member should be defined
         self.joinsource = joinsource  # Let the setter do the job
@@ -938,9 +936,9 @@ class JoinNode(Node):
         """
         # create the new join item fields
         idx = self._next_slot_index
-        newfields = dict(
-            [(field, self._add_join_item_field(field, idx)) for field in self.joinfield]
-        )
+        newfields = {
+            field: self._add_join_item_field(field, idx) for field in self.joinfield
+        }
         # increment the join slot index
         logger.debug("Added the %s join item fields %s.", self, newfields)
         self._next_slot_index += 1
@@ -1001,7 +999,7 @@ class JoinNode(Node):
     def _run_command(self, execute, copyfiles=True):
         """Collates the join inputs prior to delegating to the superclass."""
         self._collate_join_field_inputs()
-        return super(JoinNode, self)._run_command(execute, copyfiles)
+        return super()._run_command(execute, copyfiles)
 
     def _collate_join_field_inputs(self):
         """
@@ -1113,7 +1111,7 @@ class MapNode(Node):
         See Node docstring for additional keyword arguments.
         """
 
-        super(MapNode, self).__init__(interface, name, **kwargs)
+        super().__init__(interface, name, **kwargs)
         if isinstance(iterfield, (str, bytes)):
             iterfield = [iterfield]
         self.iterfield = iterfield
@@ -1284,14 +1282,14 @@ class MapNode(Node):
                     )
                 setattr(finalresult.outputs, key, values)
 
-        if returncode and any([code is not None for code in returncode]):
+        if returncode and any(code is not None for code in returncode):
             msg = []
             for i, code in enumerate(returncode):
                 if code is not None:
                     msg += ["Subnode %d failed" % i]
                     msg += ["Error: %s" % str(code)]
             raise NodeExecutionError(
-                "Subnodes of node: %s failed:\n%s" % (self.name, "\n".join(msg))
+                "Subnodes of node: {} failed:\n{}".format(self.name, "\n".join(msg))
             )
 
         return finalresult
@@ -1319,7 +1317,7 @@ class MapNode(Node):
             self._interface.inputs, fields=self.iterfield
         )
         self._inputs.trait_set(**old_inputs)
-        super(MapNode, self)._get_inputs()
+        super()._get_inputs()
 
     def _check_iterfield(self):
         """Checks iterfield
@@ -1330,18 +1328,14 @@ class MapNode(Node):
         for iterfield in self.iterfield:
             if not isdefined(getattr(self.inputs, iterfield)):
                 raise ValueError(
-                    ("Input %s was not set but it is listed " "in iterfields.")
-                    % iterfield
+                    "Input %s was not set but it is listed in iterfields." % iterfield
                 )
         if len(self.iterfield) > 1:
             first_len = len(ensure_list(getattr(self.inputs, self.iterfield[0])))
             for iterfield in self.iterfield[1:]:
                 if first_len != len(ensure_list(getattr(self.inputs, iterfield))):
                     raise ValueError(
-                        (
-                            "All iterfields of a MapNode have to "
-                            "have the same length. %s"
-                        )
+                        "All iterfields of a MapNode have to have the same length. %s"
                         % str(self.inputs)
                     )
 
@@ -1387,7 +1381,7 @@ class MapNode(Node):
                 )
             )
         except Exception as msg:
-            result.runtime.stderr = "%s\n\n%s".format(
+            result.runtime.stderr = "{}\n\n{}".format(
                 getattr(result.runtime, "stderr", ""), msg
             )
             _save_resultfile(
