@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Tests for join expansion
@@ -406,7 +405,7 @@ def test_multifield_join_node(tmpdir):
     # node and 1 post-join node.
     assert len(result.nodes()) == 10, "The number of expanded nodes is incorrect."
     # the product inputs are [2, 4], [2, 5], [3, 4], [3, 5]
-    assert set(_products) == set([8, 10, 12, 15]), (
+    assert set(_products) == {8, 10, 12, 15}, (
         "The post-join products is incorrect: %s." % _products
     )
 
