@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Utility routines for workflow graphs"""
@@ -67,13 +66,13 @@ def save_hashfile(hashfile, hashed_inputs):
     """Store a hashfile"""
     try:
         save_json(hashfile, hashed_inputs)
-    except (IOError, TypeError):
+    except (OSError, TypeError):
         err_type = sys.exc_info()[0]
         if err_type is TypeError:
             # XXX - SG current workaround is to just
             # create the hashed file and not put anything
             # in it
-            with open(hashfile, "wt") as fd:
+            with open(hashfile, "w") as fd:
                 fd.writelines(str(hashed_inputs))
 
             logger.debug("Unable to write a particular type to the json file")
@@ -333,7 +332,7 @@ def _write_inputs(node):
                 try:
                     func = create_function_from_source(val)
                 except RuntimeError:
-                    lines.append("%s.inputs.%s = '%s'" % (nodename, key, val))
+                    lines.append(f"{nodename}.inputs.{key} = '{val}'")
                 else:
                     funcname = [
                         name for name in func.__globals__ if name != "__builtins__"
@@ -345,11 +344,9 @@ def _write_inputs(node):
                         )
                         funcname = "%s_1" % funcname
                     lines.append("from nipype.utils.functions import getsource")
-                    lines.append(
-                        "%s.inputs.%s = getsource(%s)" % (nodename, key, funcname)
-                    )
+                    lines.append(f"{nodename}.inputs.{key} = getsource({funcname})")
             else:
-                lines.append("%s.inputs.%s = %s" % (nodename, key, val))
+                lines.append(f"{nodename}.inputs.{key} = {val}")
     return lines
 
 
@@ -361,7 +358,7 @@ def format_node(node, format="python", include_config=False):
     name = node.fullname.replace(".", "_")
     if format == "python":
         klass = node.interface
-        importline = "from %s import %s" % (klass.__module__, klass.__class__.__name__)
+        importline = f"from {klass.__module__} import {klass.__class__.__name__}"
         comment = "# Node: %s" % node.fullname
         spec = signature(node.interface.__init__)
         filled_args = []
@@ -372,7 +369,7 @@ def format_node(node, format="python", include_config=False):
         args = ", ".join(filled_args)
         klass_name = klass.__class__.__name__
         if isinstance(node, MapNode):
-            nodedef = '%s = MapNode(%s(%s), iterfield=%s, name="%s")' % (
+            nodedef = '{} = MapNode({}({}), iterfield={}, name="{}")'.format(
                 name,
                 klass_name,
                 args,
@@ -380,7 +377,7 @@ def format_node(node, format="python", include_config=False):
                 name,
             )
         else:
-            nodedef = '%s = Node(%s(%s), name="%s")' % (name, klass_name, args, name)
+            nodedef = f'{name} = Node({klass_name}({args}), name="{name}")'
         lines = [importline, comment, nodedef]
 
         if include_config:
@@ -390,10 +387,10 @@ def format_node(node, format="python", include_config=False):
                 comment,
                 nodedef,
             ]
-            lines.append("%s.config = %s" % (name, node.config))
+            lines.append(f"{name}.config = {node.config}")
 
         if node.iterables is not None:
-            lines.append("%s.iterables = %s" % (name, node.iterables))
+            lines.append(f"{name}.iterables = {node.iterables}")
         lines.extend(_write_inputs(node))
 
     return lines
@@ -437,11 +434,11 @@ def modify_paths(object, relative=True, basedir=None):
                 else:
                     out = os.path.abspath(os.path.join(basedir, object))
                 if not os.path.exists(out):
-                    raise IOError("File %s not found" % out)
+                    raise OSError("File %s not found" % out)
             else:
                 out = object
         else:
-            raise TypeError("Object {} is undefined".format(object))
+            raise TypeError(f"Object {object} is undefined")
     return out
 
 
@@ -460,9 +457,9 @@ def get_print_name(node, simple_form=True):
         if len(pkglist) > 2:
             destclass = ".%s" % pkglist[2]
         if simple_form:
-            name = node.fullname + destclass
+            name = f"{node.fullname}{destclass}"
         else:
-            name = ".".join([node.fullname, interface]) + destclass
+            name = f"{node.fullname}.{interface}{destclass}"
     if simple_form:
         parts = name.split(".")
         if len(parts) > 2:
@@ -513,15 +510,15 @@ def _write_detailed_dot(graph, dotfilename):
     edges = []
     for n in nx.topological_sort(graph):
         nodename = n.itername
-        inports = []
+        in_ports = []
         for u, v, d in graph.in_edges(nbunch=n, data=True):
             for cd in d["connect"]:
                 if isinstance(cd[0], (str, bytes)):
                     outport = cd[0]
                 else:
                     outport = cd[0][0]
-                inport = cd[1]
-                ipstrip = "in%s" % _replacefunk(inport)
+                in_port = cd[1]
+                ipstrip = "in%s" % _replacefunk(in_port)
                 opstrip = "out%s" % _replacefunk(outport)
                 edges.append(
                     "%s:%s:e -> %s:%s:w;"
@@ -532,11 +529,11 @@ def _write_detailed_dot(graph, dotfilename):
                         ipstrip,
                     )
                 )
-                if inport not in inports:
-                    inports.append(inport)
+                if in_port not in in_ports:
+                    in_ports.append(in_port)
         inputstr = (
             ["{IN"]
-            + ["|<in%s> %s" % (_replacefunk(ip), ip) for ip in sorted(inports)]
+            + [f"|<in{_replacefunk(ip)}> {ip}" for ip in sorted(in_ports)]
             + ["}"]
         )
         outports = []
@@ -550,10 +547,7 @@ def _write_detailed_dot(graph, dotfilename):
                     outports.append(outport)
         outputstr = (
             ["{OUT"]
-            + [
-                "|<out%s> %s" % (_replacefunk(oport), oport)
-                for oport in sorted(outports)
-            ]
+            + [f"|<out{_replacefunk(oport)}> {oport}" for oport in sorted(outports)]
             + ["}"]
         )
         srcpackage = ""
@@ -562,7 +556,7 @@ def _write_detailed_dot(graph, dotfilename):
             if len(pkglist) > 2:
                 srcpackage = pkglist[2]
         srchierarchy = ".".join(nodename.split(".")[1:-1])
-        nodenamestr = "{ %s | %s | %s }" % (
+        nodenamestr = "{{ {} | {} | {} }}".format(
             nodename.split(".")[-1],
             srcpackage,
             srchierarchy,
@@ -580,7 +574,7 @@ def _write_detailed_dot(graph, dotfilename):
     for edge in sorted(edges):
         text.append(edge)
     text.append("}")
-    with open(dotfilename, "wt") as filep:
+    with open(dotfilename, "w") as filep:
         filep.write("\n".join(text))
     return text
 
@@ -651,8 +645,7 @@ def walk(children, level=0, path=None, usename=True):
         else:
             path[level] = child
         # Recurse into the next level
-        for child_paths in walk(tail, level + 1, path, usename):
-            yield child_paths
+        yield from walk(tail, level + 1, path, usename)
 
 
 def synchronize_iterables(iterables):
@@ -696,15 +689,10 @@ def evaluate_connect_function(function_source, args, first_arg):
     try:
         output_value = func(first_arg, *list(args))
     except NameError as e:
-        if e.args[0].startswith("global name") and e.args[0].endswith("is not defined"):
-            e.args = (
-                e.args[0],
-                (
-                    "Due to engine constraints all imports have to be done "
-                    "inside each function definition"
-                ),
-            )
-        raise e
+        raise NameError(
+            f"{e}: Due to engine constraints all imports have to be done inside each "
+            " function definition."
+        )
     return output_value
 
 
@@ -758,10 +746,8 @@ def _merge_graphs(
         # used at the same level. The use of the template below for naming
         # updates to nodes is the general solution.
         raise Exception(
-            (
-                "Execution graph does not have a unique set of node "
-                "names. Please rerun the workflow"
-            )
+            "Execution graph does not have a unique set of node "
+            "names. Please rerun the workflow"
         )
     edgeinfo = {}
     for n in list(subgraph.nodes()):
@@ -861,7 +847,7 @@ def _identity_nodes(graph, include_iterables):
         node
         for node in nx.topological_sort(graph)
         if isinstance(node.interface, IdentityInterface)
-        and (include_iterables or getattr(node, "iterables") is None)
+        and (include_iterables or node.iterables is None)
     ]
 
 
@@ -895,34 +881,34 @@ def _node_ports(graph, node):
     for _, v, d in graph.out_edges(node, data=True):
         for src, dest in d["connect"]:
             if isinstance(src, tuple):
-                srcport = src[0]
+                src_port = src[0]
             else:
-                srcport = src
-            if srcport not in portoutputs:
-                portoutputs[srcport] = []
-            portoutputs[srcport].append((v, dest, src))
+                src_port = src
+            if src_port not in portoutputs:
+                portoutputs[src_port] = []
+            portoutputs[src_port].append((v, dest, src))
     return (portinputs, portoutputs)
 
 
 def _propagate_root_output(graph, node, field, connections):
     """Propagates the given graph root node output port
     field connections to the out-edge destination nodes."""
-    for destnode, inport, src in connections:
+    for destnode, in_port, src in connections:
         value = getattr(node.inputs, field)
         if isinstance(src, tuple):
             value = evaluate_connect_function(src[1], src[2], value)
-        destnode.set_input(inport, value)
+        destnode.set_input(in_port, value)
 
 
 def _propagate_internal_output(graph, node, field, connections, portinputs):
     """Propagates the given graph internal node output port
     field connections to the out-edge source node and in-edge
     destination nodes."""
-    for destnode, inport, src in connections:
+    for destnode, in_port, src in connections:
         if field in portinputs:
-            srcnode, srcport = portinputs[field]
-            if isinstance(srcport, tuple) and isinstance(src, tuple):
-                src_func = srcport[1].split("\\n")[0]
+            srcnode, src_port = portinputs[field]
+            if isinstance(src_port, tuple) and isinstance(src, tuple):
+                src_func = src_port[1].split("\\n")[0]
                 dst_func = src[1].split("\\n")[0]
                 raise ValueError(
                     "Does not support two inline functions "
@@ -933,9 +919,9 @@ def _propagate_internal_output(graph, node, field, connections, portinputs):
 
             connect = graph.get_edge_data(srcnode, destnode, default={"connect": []})
             if isinstance(src, tuple):
-                connect["connect"].append(((srcport, src[1], src[2]), inport))
+                connect["connect"].append(((src_port, src[1], src[2]), in_port))
             else:
-                connect = {"connect": [(srcport, inport)]}
+                connect = {"connect": [(src_port, in_port)]}
             old_connect = graph.get_edge_data(
                 srcnode, destnode, default={"connect": []}
             )
@@ -945,7 +931,7 @@ def _propagate_internal_output(graph, node, field, connections, portinputs):
             value = getattr(node.inputs, field)
             if isinstance(src, tuple):
                 value = evaluate_connect_function(src[1], src[2], value)
-            destnode.set_input(inport, value)
+            destnode.set_input(in_port, value)
 
 
 def generate_expanded_graph(graph_in):
@@ -1013,11 +999,9 @@ def generate_expanded_graph(graph_in):
             # find the unique iterable source node in the graph
             try:
                 iter_src = next(
-                    (
-                        node
-                        for node in graph_in.nodes()
-                        if node.name == src_name and nx.has_path(graph_in, node, inode)
-                    )
+                    node
+                    for node in graph_in.nodes()
+                    if node.name == src_name and nx.has_path(graph_in, node, inode)
                 )
             except StopIteration:
                 raise ValueError(
@@ -1039,13 +1023,9 @@ def generate_expanded_graph(graph_in):
             # The itersource iterables is a {field: lookup} dictionary, where the
             # lookup is a {source key: iteration list} dictionary. Look up the
             # current iterable value using the predecessor itersource input values.
-            iter_dict = dict(
-                [
-                    (field, lookup[key])
-                    for field, lookup in inode.iterables
-                    if key in lookup
-                ]
-            )
+            iter_dict = {
+                field: lookup[key] for field, lookup in inode.iterables if key in lookup
+            }
 
             # convert the iterables to the standard {field: function} format
 
@@ -1061,7 +1041,7 @@ def generate_expanded_graph(graph_in):
         logger.debug("node: %s iterables: %s", inode, iterables)
 
         # collect the subnodes to expand
-        subnodes = [s for s in dfs_preorder(graph_in, inode)]
+        subnodes = list(dfs_preorder(graph_in, inode))
         prior_prefix = [re.findall(r"\.(.)I", s._id) for s in subnodes if s._id]
         prior_prefix = sorted([l for item in prior_prefix for l in item])
         if not prior_prefix:
@@ -1114,7 +1094,7 @@ def generate_expanded_graph(graph_in):
                             expansions[src_id].append(node)
             for in_id, in_nodes in list(expansions.items()):
                 logger.debug(
-                    "The join node %s input %s was expanded" " to %d nodes.",
+                    "The join node %s input %s was expanded to %d nodes.",
                     jnode,
                     in_id,
                     len(in_nodes),
@@ -1235,9 +1215,7 @@ def _standardize_iterables(node):
     if node.synchronize:
         if len(iterables) == 2:
             first, last = iterables
-            if all(
-                (isinstance(item, (str, bytes)) and item in fields for item in first)
-            ):
+            if all(isinstance(item, (str, bytes)) and item in fields for item in first):
                 iterables = _transpose_iterables(first, last)
 
     # Convert a tuple to a list
@@ -1279,16 +1257,14 @@ def _validate_iterables(node, iterables, fields):
         try:
             if len(item) != 2:
                 raise ValueError(
-                    "The %s iterables is not a [(field, values)]" " list" % node.name
+                    "The %s iterables is not a [(field, values)] list" % node.name
                 )
         except TypeError as e:
-            raise TypeError(
-                "A %s iterables member is not iterable: %s" % (node.name, e)
-            )
+            raise TypeError(f"A {node.name} iterables member is not iterable: {e}")
         field, _ = item
         if field not in fields:
             raise ValueError(
-                "The %s iterables field is unrecognized: %s" % (node.name, field)
+                f"The {node.name} iterables field is unrecognized: {field}"
             )
 
 
@@ -1303,7 +1279,7 @@ def _transpose_iterables(fields, values):
     Otherwise, the result is a list of (field: value list) pairs.
     """
     if isinstance(values, dict):
-        transposed = dict([(field, defaultdict(list)) for field in fields])
+        transposed = {field: defaultdict(list) for field in fields}
         for key, tuples in list(values.items()):
             for kvals in tuples:
                 for idx, val in enumerate(kvals):
@@ -1398,9 +1374,9 @@ def format_dot(dotfilename, format="png"):
     """Dump a directed graph (Linux only; install via `brew` on OSX)"""
     try:
         formatted_dot, _ = _run_dot(dotfilename, format_ext=format)
-    except IOError as ioe:
+    except OSError as ioe:
         if "could not be found" in str(ioe):
-            raise IOError("Cannot draw directed graph; executable 'dot' is unavailable")
+            raise OSError("Cannot draw directed graph; executable 'dot' is unavailable")
         else:
             raise ioe
     return formatted_dot
@@ -1411,8 +1387,8 @@ def _run_dot(dotfilename, format_ext):
         return dotfilename, None
 
     dot_base = os.path.splitext(dotfilename)[0]
-    formatted_dot = "{}.{}".format(dot_base, format_ext)
-    cmd = 'dot -T{} -o"{}" "{}"'.format(format_ext, formatted_dot, dotfilename)
+    formatted_dot = f"{dot_base}.{format_ext}"
+    cmd = f'dot -T{format_ext} -o"{formatted_dot}" "{dotfilename}"'
     res = CommandLine(cmd, terminal_output="allatonce", resource_monitor=False).run()
     return formatted_dot, res
 
@@ -1498,23 +1474,21 @@ def clean_working_directory(
     needed_files = temp
     logger.debug("Needed files: %s", ";".join(needed_files))
     logger.debug("Needed dirs: %s", ";".join(needed_dirs))
-    files2remove = []
     if str2bool(config["execution"]["remove_unnecessary_outputs"]):
-        for f in walk_files(cwd):
-            if f not in needed_files:
-                if not needed_dirs:
-                    files2remove.append(f)
-                elif not any([f.startswith(dname) for dname in needed_dirs]):
-                    files2remove.append(f)
+        files2remove = [
+            f
+            for f in walk_files(cwd)
+            if f not in needed_files and not f.startswith(tuple(needed_dirs))
+        ]
+    elif not str2bool(config["execution"]["keep_inputs"]):
+        input_files = {
+            path for path, type in walk_outputs(inputs.trait_get()) if type == "f"
+        }
+        files2remove = [
+            f for f in walk_files(cwd) if f in input_files and f not in needed_files
+        ]
     else:
-        if not str2bool(config["execution"]["keep_inputs"]):
-            input_files = []
-            inputdict = inputs.trait_get()
-            input_files.extend(walk_outputs(inputdict))
-            input_files = [path for path, type in input_files if type == "f"]
-            for f in walk_files(cwd):
-                if f in input_files and f not in needed_files:
-                    files2remove.append(f)
+        files2remove = []
     logger.debug("Removing files: %s", ";".join(files2remove))
     for f in files2remove:
         os.remove(f)
@@ -1584,7 +1558,7 @@ def write_workflow_prov(graph, filename=None, format="all"):
         _, hashval, _, _ = node.hash_exists()
         attrs = {
             pm.PROV["type"]: nipype_ns[classname],
-            pm.PROV["label"]: "_".join((classname, node.name)),
+            pm.PROV["label"]: f"{classname}_{node.name}",
             nipype_ns["hashval"]: hashval,
         }
         process = ps.g.activity(get_id(), None, None, attrs)
@@ -1668,7 +1642,7 @@ def write_workflow_resources(graph, filename=None, append=None):
     # If we append different runs, then we will see different
     # "bursts" of timestamps corresponding to those executions.
     if append and os.path.isfile(filename):
-        with open(filename, "r") as rsf:
+        with open(filename) as rsf:
             big_dict = json.load(rsf)
 
     for _, node in enumerate(graph.nodes()):
@@ -1677,13 +1651,13 @@ def write_workflow_resources(graph, filename=None, append=None):
 
         params = ""
         if node.parameterization:
-            params = "_".join(["{}".format(p) for p in node.parameterization])
+            params = "_".join([f"{p}" for p in node.parameterization])
 
         try:
             rt_list = node.result.runtime
         except Exception:
             logger.warning(
-                "Could not access runtime info for node %s" " (%s interface)",
+                "Could not access runtime info for node %s (%s interface)",
                 nodename,
                 classname,
             )
@@ -1729,16 +1703,12 @@ def topological_sort(graph, depth_first=False):
     logger.debug("Performing depth first search")
     nodes = []
     groups = []
-    group = 0
     G = nx.Graph()
     G.add_nodes_from(graph.nodes())
     G.add_edges_from(graph.edges())
     components = nx.connected_components(G)
-    for desc in components:
-        group += 1
-        indices = []
-        for node in desc:
-            indices.append(nodesort.index(node))
+    for group, desc in enumerate(components, start=1):
+        indices = [nodesort.index(node) for node in desc]
         nodes.extend(
             np.array(nodesort)[np.array(indices)[np.argsort(indices)]].tolist()
         )
