@@ -1,5 +1,4 @@
 #!/usr/bin/env python
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Defines functionality for pipelined execution of interfaces
@@ -9,7 +8,6 @@ The `Workflow` class provides core functionality for batch processing.
 import os
 import os.path as op
 import sys
-from datetime import datetime
 from copy import deepcopy
 import pickle
 import shutil
@@ -17,6 +15,7 @@ import shutil
 import numpy as np
 
 from ... import config, logging
+from ...utils.datetime import utcnow
 from ...utils.misc import str2bool
 from ...utils.functions import getsource, create_function_from_source
 
@@ -56,7 +55,7 @@ class Workflow(EngineBase):
         """
         import networkx as nx
 
-        super(Workflow, self).__init__(name, base_dir)
+        super().__init__(name, base_dir)
         self._graph = nx.DiGraph()
 
         self._nodes_cache = set()
@@ -78,7 +77,7 @@ class Workflow(EngineBase):
             unique name for the workflow
 
         """
-        clone = super(Workflow, self).clone(name)
+        clone = super().clone(name)
         clone._reset_hierarchy()
         return clone
 
@@ -152,7 +151,7 @@ class Workflow(EngineBase):
                     " src[%s] dest[%s] workflow[%s]"
                 ) % (srcnode, destnode, self.name)
 
-                raise IOError(msg)
+                raise OSError(msg)
             if (srcnode not in newnodes) and not self._has_node(srcnode):
                 newnodes.add(srcnode)
             if (destnode not in newnodes) and not self._has_node(destnode):
@@ -192,10 +191,8 @@ connected.
                     and (
                         ".io" in str(destnode._interface.__class__)
                         or any(
-                            [
-                                ".io" in str(val)
-                                for val in destnode._interface.__class__.__bases__
-                            ]
+                            ".io" in str(val)
+                            for val in destnode._interface.__class__.__bases__
                         )
                     )
                 ):
@@ -206,10 +203,8 @@ connected.
                     and (
                         ".io" in str(srcnode._interface.__class__)
                         or any(
-                            [
-                                ".io" in str(val)
-                                for val in srcnode._interface.__class__.__bases__
-                            ]
+                            ".io" in str(val)
+                            for val in srcnode._interface.__class__.__bases__
                         )
                     )
                 ):
@@ -232,9 +227,7 @@ connected.
                 connected_ports[destnode].add(dest)
         infostr = []
         for info in not_found:
-            infostr += [
-                "Module %s has no %sput called %s\n" % (info[1], info[0], info[2])
-            ]
+            infostr += [f"Module {info[1]} has no {info[0]}put called {info[2]}\n"]
         if not_found:
             raise Exception("\n".join(["Some connections were not found"] + infostr))
 
@@ -292,7 +285,7 @@ connected.
         for srcnode, dstnode, conn in connection_list:
             logger.debug("disconnect(): %s->%s %s", srcnode, dstnode, str(conn))
             if self in [srcnode, dstnode]:
-                raise IOError(
+                raise OSError(
                     "Workflow connect cannot contain itself as node: src[%s] "
                     "dest[%s] workflow[%s]"
                 ) % (srcnode, dstnode, self.name)
@@ -304,11 +297,12 @@ connected.
             edge_data = self._graph.get_edge_data(srcnode, dstnode, {"connect": []})
             ed_conns = [(c[0], c[1]) for c in edge_data["connect"]]
 
-            remove = []
-            for edge in conn:
-                if edge in ed_conns:
-                    # idx = ed_conns.index(edge)
-                    remove.append((edge[0], edge[1]))
+            remove = [
+                # idx = ed_conns.index(edge)
+                (edge[0], edge[1])
+                for edge in conn
+                if edge in ed_conns
+            ]
 
             logger.debug("disconnect(): remove list %s", str(remove))
             for el in remove:
@@ -332,12 +326,12 @@ connected.
         all_nodes = self._get_all_nodes()
         for node in nodes:
             if node in all_nodes:
-                raise IOError("Node %s already exists in the workflow" % node)
+                raise OSError("Node %s already exists in the workflow" % node)
             if isinstance(node, Workflow):
                 for subnode in node._get_all_nodes():
                     if subnode in all_nodes:
-                        raise IOError(
-                            ("Subnode %s of node %s already exists " "in the workflow")
+                        raise OSError(
+                            "Subnode %s of node %s already exists in the workflow"
                             % (subnode, node)
                         )
             newnodes.append(node)
@@ -397,10 +391,7 @@ connected.
         for node in nx.topological_sort(self._graph):
             if isinstance(node, Workflow):
                 outlist.extend(
-                    [
-                        ".".join((node.name, nodename))
-                        for nodename in node.list_node_names()
-                    ]
+                    f"{node.name}.{nodename}" for nodename in node.list_node_names()
                 )
             else:
                 outlist.append(node.name)
@@ -486,16 +477,11 @@ connected.
     def write_hierarchical_dotfile(
         self, dotfilename=None, colored=False, simple_form=True
     ):
-        dotlist = ["digraph %s{" % self.name]
-        dotlist.append(
-            self._get_dot(prefix="  ", colored=colored, simple_form=simple_form)
-        )
-        dotlist.append("}")
-        dotstr = "\n".join(dotlist)
+        dotlist = self._get_dot(prefix="  ", colored=colored, simple_form=simple_form)
+        dotstr = f"digraph {self.name}{{\n{dotlist}\n}}"
         if dotfilename:
-            fp = open(dotfilename, "wt")
-            fp.writelines(dotstr)
-            fp.close()
+            with open(dotfilename, "w") as fp:
+                fp.writelines(dotstr)
         else:
             logger.info(dotstr)
 
@@ -526,16 +512,16 @@ connected.
 
         all_lines = None
         lines = ["# Workflow"]
-        importlines = ["from nipype.pipeline.engine import Workflow, " "Node, MapNode"]
+        importlines = ["from nipype.pipeline.engine import Workflow, Node, MapNode"]
         functions = {}
         if format == "python":
             connect_template = '%s.connect(%%s, %%s, %%s, "%%s")' % self.name
             connect_template2 = '%s.connect(%%s, "%%s", %%s, "%%s")' % self.name
-            wfdef = '%s = Workflow("%s")' % (self.name, self.name)
+            wfdef = f'{self.name} = Workflow("{self.name}")'
             lines.append(wfdef)
             if include_config:
-                lines.append("%s.config = %s" % (self.name, self.config))
-            for idx, node in enumerate(nodes):
+                lines.append(f"{self.name}.config = {self.config}")
+            for node in nodes:
                 nodename = node.fullname.replace(".", "_")
                 # write nodes
                 nodelines = format_node(
@@ -563,7 +549,7 @@ connected.
                                 ][0]
                                 functions[args[1]] = funcname
                             args[1] = funcname
-                            args = tuple([arg for arg in args if arg])
+                            args = tuple(arg for arg in args if arg)
                             line_args = (
                                 u.fullname.replace(".", "_"),
                                 args,
@@ -582,13 +568,14 @@ connected.
                             )
                             lines.append(connect_template2 % line_args)
             functionlines = ["# Functions"]
-            for function in functions:
-                functionlines.append(pickle.loads(function).rstrip())
+            functionlines.extend(
+                pickle.loads(function).rstrip() for function in functions
+            )
             all_lines = importlines + functionlines + lines
 
             if not filename:
-                filename = "%s%s.py" % (prefix, self.name)
-            with open(filename, "wt") as fp:
+                filename = f"{prefix}{self.name}.py"
+            with open(filename, "w") as fp:
                 fp.writelines("\n".join(all_lines))
         return all_lines
 
@@ -636,7 +623,7 @@ connected.
         if str2bool(self.config["execution"]["create_report"]):
             self._write_report_info(self.base_dir, self.name, execgraph)
         runner.run(execgraph, updatehash=updatehash, config=self.config)
-        datestr = datetime.utcnow().strftime("%Y%m%dT%H%M%S")
+        datestr = utcnow().strftime("%Y%m%dT%H%M%S")
         if str2bool(self.config["execution"]["write_provenance"]):
             prov_base = op.join(self.base_dir, "workflow_provenance_%s" % datestr)
             logger.info("Provenance file prefix: %s" % prov_base)
@@ -672,7 +659,7 @@ connected.
             report_file = "%s/_report/report.rst" % node.output_dir().replace(
                 report_dir, ""
             )
-            result_file = "%s/result_%s.pklz" % (
+            result_file = "{}/result_{}.pklz".format(
                 node.output_dir().replace(report_dir, ""),
                 node.name,
             )
@@ -763,10 +750,10 @@ connected.
                 try:
                     this_node_lineage = node_lineage[idx]
                 except IndexError:
-                    raise IOError('Duplicate node name "%s" found.' % node.name)
+                    raise OSError('Duplicate node name "%s" found.' % node.name)
                 else:
                     if this_node_lineage in [node._hierarchy, self.name]:
-                        raise IOError('Duplicate node name "%s" found.' % node.name)
+                        raise OSError('Duplicate node name "%s" found.' % node.name)
             else:
                 node_names.append(node.name)
 
@@ -854,10 +841,11 @@ connected.
             if isinstance(node, Workflow):
                 setattr(inputdict, node.name, node.inputs)
             else:
-                taken_inputs = []
-                for _, _, d in self._graph.in_edges(nbunch=node, data=True):
-                    for cd in d["connect"]:
-                        taken_inputs.append(cd[1])
+                taken_inputs = [
+                    cd[1]
+                    for _, _, d in self._graph.in_edges(nbunch=node, data=True)
+                    for cd in d["connect"]
+                ]
                 unconnectedinputs = TraitedSpec()
                 for key, trait in list(node.inputs.items()):
                     if key not in taken_inputs:
@@ -939,7 +927,7 @@ connected.
             if isinstance(node, Workflow):
                 node._reset_hierarchy()
                 for innernode in node._graph.nodes():
-                    innernode._hierarchy = ".".join((self.name, innernode._hierarchy))
+                    innernode._hierarchy = f"{self.name}.{innernode._hierarchy}"
             else:
                 node._hierarchy = self.name
 
@@ -951,7 +939,7 @@ connected.
         nodes2remove = []
         if not nx.is_directed_acyclic_graph(self._graph):
             raise Exception(
-                ("Workflow: %s is not a directed acyclic graph " "(DAG)") % self.name
+                ("Workflow: %s is not a directed acyclic graph (DAG)") % self.name
             )
         nodes = list(self._graph.nodes)
         for node in nodes:
@@ -1003,7 +991,7 @@ connected.
                 # logger.debug('expanding workflow: %s', node)
                 node._generate_flatgraph()
                 for innernode in node._graph.nodes():
-                    innernode._hierarchy = ".".join((self.name, innernode._hierarchy))
+                    innernode._hierarchy = f"{self.name}.{innernode._hierarchy}"
                 self._graph.add_nodes_from(node._graph.nodes())
                 self._graph.add_edges_from(node._graph.edges(data=True))
         if nodes2remove:
@@ -1037,7 +1025,7 @@ connected.
         if level > len(colorset) - 2:
             level = 3  # Loop back to blue
 
-        dotlist = ['%slabel="%s";' % (prefix, self.name)]
+        dotlist = [f'{prefix}label="{self.name}";']
         for node in nx.topological_sort(self._graph):
             fullname = ".".join(hierarchy + [node.fullname])
             nodename = fullname.replace(".", "_")
@@ -1057,7 +1045,7 @@ connected.
                 else:
                     if colored:
                         dotlist.append(
-                            ('%s[label="%s", style=filled,' ' fillcolor="%s"];')
+                            ('%s[label="%s", style=filled, fillcolor="%s"];')
                             % (nodename, node_class_name, colorset[level])
                         )
                     else:
@@ -1071,23 +1059,25 @@ connected.
                 nodename = fullname.replace(".", "_")
                 dotlist.append("subgraph cluster_%s {" % nodename)
                 if colored:
-                    dotlist.append(
-                        prefix + prefix + 'edge [color="%s"];' % (colorset[level + 1])
+                    dotlist.extend(
+                        (
+                            f'{prefix * 2}edge [color="{colorset[level + 1]}"];',
+                            f"{prefix * 2}style=filled;",
+                            f'{prefix * 2}fillcolor="{colorset[level + 2]}";',
+                        )
                     )
-                    dotlist.append(prefix + prefix + "style=filled;")
-                    dotlist.append(
-                        prefix + prefix + 'fillcolor="%s";' % (colorset[level + 2])
-                    )
-                dotlist.append(
-                    node._get_dot(
-                        prefix=prefix + prefix,
-                        hierarchy=hierarchy + [self.name],
-                        colored=colored,
-                        simple_form=simple_form,
-                        level=level + 3,
+                dotlist.extend(
+                    (
+                        node._get_dot(
+                            prefix=prefix + prefix,
+                            hierarchy=hierarchy + [self.name],
+                            colored=colored,
+                            simple_form=simple_form,
+                            level=level + 3,
+                        ),
+                        "}",
                     )
                 )
-                dotlist.append("}")
             else:
                 for subnode in self._graph.successors(node):
                     if node._hierarchy != subnode._hierarchy:
@@ -1097,8 +1087,10 @@ connected.
                         subnodefullname = ".".join(hierarchy + [subnode.fullname])
                         nodename = nodefullname.replace(".", "_")
                         subnodename = subnodefullname.replace(".", "_")
-                        for _ in self._graph.get_edge_data(node, subnode)["connect"]:
-                            dotlist.append("%s -> %s;" % (nodename, subnodename))
+                        dotlist.extend(
+                            f"{nodename} -> {subnodename};"
+                            for _ in self._graph.get_edge_data(node, subnode)["connect"]
+                        )
                         logger.debug("connection: %s", dotlist[-1])
         # add between workflow connections
         for u, v, d in self._graph.edges(data=True):
