@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Local serial workflow execution
@@ -51,7 +50,7 @@ class LinearPlugin(PluginBase):
                 # node might fail
                 crashfile = report_crash(node)
                 # remove dependencies from queue
-                subnodes = [s for s in dfs_preorder(graph, node)]
+                subnodes = list(dfs_preorder(graph, node))
                 notrun.append(
                     {"node": node, "dependents": subnodes, "crashfile": crashfile}
                 )
