@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 """Parallel workflow execution via LSF
 """
 
@@ -32,14 +31,14 @@ class LSFPlugin(SGELikeBatchManagerBase):
         self._retry_timeout = 2
         self._max_tries = 2
         self._bsub_args = ""
-        if "plugin_args" in kwargs and kwargs["plugin_args"]:
+        if kwargs.get("plugin_args"):
             if "retry_timeout" in kwargs["plugin_args"]:
                 self._retry_timeout = kwargs["plugin_args"]["retry_timeout"]
             if "max_tries" in kwargs["plugin_args"]:
                 self._max_tries = kwargs["plugin_args"]["max_tries"]
             if "bsub_args" in kwargs["plugin_args"]:
                 self._bsub_args = kwargs["plugin_args"]["bsub_args"]
-        super(LSFPlugin, self).__init__(template, **kwargs)
+        super().__init__(template, **kwargs)
 
     def _is_pending(self, taskid):
         """LSF lists a status of 'PEND' when a job has been submitted but is
@@ -55,10 +54,9 @@ class LSFPlugin(SGELikeBatchManagerBase):
         result = cmd.run(ignore_exception=True)
         iflogger.setLevel(oldlevel)
         # logger.debug(result.runtime.stdout)
-        if "DONE" in result.runtime.stdout or "EXIT" in result.runtime.stdout:
-            return False
-        else:
-            return True
+        return (
+            "DONE" not in result.runtime.stdout and "EXIT" not in result.runtime.stdout
+        )
 
     def _submit_batchtask(self, scriptfile, node):
         cmd = CommandLine(
@@ -71,15 +69,15 @@ class LSFPlugin(SGELikeBatchManagerBase):
         if self._bsub_args:
             bsubargs = self._bsub_args
         if "bsub_args" in node.plugin_args:
-            if "overwrite" in node.plugin_args and node.plugin_args["overwrite"]:
+            if node.plugin_args.get("overwrite"):
                 bsubargs = node.plugin_args["bsub_args"]
             else:
                 bsubargs += " " + node.plugin_args["bsub_args"]
         if "-o" not in bsubargs:  # -o outfile
-            bsubargs = "%s -o %s" % (bsubargs, scriptfile + ".log")
+            bsubargs = "{} -o {}".format(bsubargs, scriptfile + ".log")
         if "-e" not in bsubargs:
             # -e error file
-            bsubargs = "%s -e %s" % (bsubargs, scriptfile + ".log")
+            bsubargs = "{} -e {}".format(bsubargs, scriptfile + ".log")
         if node._hierarchy:
             jobname = ".".join((dict(os.environ)["LOGNAME"], node._hierarchy, node._id))
         else:
@@ -87,7 +85,7 @@ class LSFPlugin(SGELikeBatchManagerBase):
         jobnameitems = jobname.split(".")
         jobnameitems.reverse()
         jobname = ".".join(jobnameitems)
-        cmd.inputs.args = "%s -J %s sh %s" % (
+        cmd.inputs.args = "{} -J {} sh {}".format(
             bsubargs,
             jobname,
             scriptfile,
@@ -108,7 +106,7 @@ class LSFPlugin(SGELikeBatchManagerBase):
                     raise RuntimeError(
                         "\n".join(
                             (
-                                ("Could not submit lsf task" " for node %s") % node._id,
+                                "Could not submit lsf task for node %s" % node._id,
                                 str(e),
                             )
                         )
@@ -121,7 +119,7 @@ class LSFPlugin(SGELikeBatchManagerBase):
         if match:
             taskid = int(match.groups()[0])
         else:
-            raise IOError(
+            raise OSError(
                 "Can't parse submission job output id: %s" % result.runtime.stdout
             )
         self._pending[taskid] = node.output_dir()
