@@ -1,6 +1,6 @@
-# -*- coding: utf-8 -*-
 """Parallel workflow execution via SGE
 """
+
 import os
 import sys
 
@@ -47,7 +47,7 @@ class SGEGraphPlugin(GraphPluginBase):
     def __init__(self, **kwargs):
         self._qsub_args = ""
         self._dont_resubmit_completed_jobs = False
-        if "plugin_args" in kwargs and kwargs["plugin_args"]:
+        if kwargs.get("plugin_args"):
             plugin_args = kwargs["plugin_args"]
             if "template" in plugin_args:
                 self._template = plugin_args["template"]
@@ -59,7 +59,7 @@ class SGEGraphPlugin(GraphPluginBase):
                 self._dont_resubmit_completed_jobs = plugin_args[
                     "dont_resubmit_completed_jobs"
                 ]
-        super(SGEGraphPlugin, self).__init__(**kwargs)
+        super().__init__(**kwargs)
 
     def _submit_graph(self, pyfiles, dependencies, nodes):
         def make_job_name(jobnumber, nodeslist):
@@ -68,7 +68,7 @@ class SGEGraphPlugin(GraphPluginBase):
             - nodeslist: The name of the node being processed
             - return: A string representing this job to be displayed by SGE
             """
-            job_name = "j{0}_{1}".format(jobnumber, nodeslist[jobnumber]._id)
+            job_name = f"j{jobnumber}_{nodeslist[jobnumber]._id}"
             # Condition job_name to be a valid bash identifier (i.e. - is invalid)
             job_name = job_name.replace("-", "_").replace(".", "_").replace(":", "_")
             return job_name
@@ -96,7 +96,7 @@ class SGEGraphPlugin(GraphPluginBase):
 
                 cache_doneness_per_node[idx] = node_status_done
 
-        with open(submitjobsfile, "wt") as fp:
+        with open(submitjobsfile, "w") as fp:
             fp.writelines("#!/usr/bin/env bash\n")
             fp.writelines("# Condense format attempted\n")
             for idx, pyscript in enumerate(pyfiles):
@@ -110,9 +110,7 @@ class SGEGraphPlugin(GraphPluginBase):
 
                     batch_dir, name = os.path.split(pyscript)
                     name = ".".join(name.split(".")[:-1])
-                    batchscript = "\n".join(
-                        (template, "%s %s" % (sys.executable, pyscript))
-                    )
+                    batchscript = "\n".join((template, f"{sys.executable} {pyscript}"))
                     batchscriptfile = os.path.join(
                         batch_dir, "batchscript_%s.sh" % name
                     )
@@ -120,7 +118,7 @@ class SGEGraphPlugin(GraphPluginBase):
                     batchscriptoutfile = batchscriptfile + ".o"
                     batchscripterrfile = batchscriptfile + ".e"
 
-                    with open(batchscriptfile, "wt") as batchfp:
+                    with open(batchscriptfile, "w") as batchfp:
                         batchfp.writelines(batchscript)
                         batchfp.close()
                     deps = ""
@@ -132,9 +130,7 @@ class SGEGraphPlugin(GraphPluginBase):
                                 not self._dont_resubmit_completed_jobs
                                 or not cache_doneness_per_node[jobid]
                             ):
-                                values += "${{{0}}},".format(
-                                    make_job_name(jobid, nodes)
-                                )
+                                values += f"${{{make_job_name(jobid, nodes)}}},"
                         if (
                             values != " "
                         ):  # i.e. if some jobs were added to dependency list
@@ -144,10 +140,10 @@ class SGEGraphPlugin(GraphPluginBase):
                     # Do not use default output locations if they are set in self._qsub_args
                     stderrFile = ""
                     if self._qsub_args.count("-e ") == 0:
-                        stderrFile = "-e {errFile}".format(errFile=batchscripterrfile)
+                        stderrFile = f"-e {batchscripterrfile}"
                     stdoutFile = ""
                     if self._qsub_args.count("-o ") == 0:
-                        stdoutFile = "-o {outFile}".format(outFile=batchscriptoutfile)
+                        stdoutFile = f"-o {batchscriptoutfile}"
                     full_line = "{jobNm}=$(qsub {outFileOption} {errFileOption} {extraQSubArgs} {dependantIndex} -N {jobNm} {batchscript} | awk '/^Your job/{{print $3}}')\n".format(
                         jobNm=jobname,
                         outFileOption=stdoutFile,
