@@ -1,10 +1,7 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Tests for the engine module
 """
-import numpy as np
-import scipy.sparse as ssp
 import re
 
 from unittest import mock
