@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Common graph operations for execution
@@ -55,8 +54,8 @@ another exception occurred:\n\n{}.""".format(
     try:
         login_name = getpass.getuser()
     except KeyError:
-        login_name = "UID{:d}".format(os.getuid())
-    crashfile = "crash-%s-%s-%s-%s" % (timeofcrash, login_name, name, str(uuid.uuid4()))
+        login_name = f"UID{os.getuid():d}"
+    crashfile = f"crash-{timeofcrash}-{login_name}-{name}-{uuid.uuid4()}"
     crashdir = node.config["execution"].get("crashdump_dir", os.getcwd())
 
     os.makedirs(crashdir, exist_ok=True)
@@ -84,10 +83,8 @@ def report_nodes_not_run(notrun):
     if notrun:
         logger.info("***********************************")
         for info in notrun:
-            logger.error(
-                "could not run node: %s"
-                % ".".join((info["node"]._hierarchy, info["node"]._id))
-            )
+            node = info["node"]
+            logger.error(f"could not run node: {node._hierarchy}.{node._id}")
             logger.info("crashfile: %s" % info["crashfile"])
             logger.debug("The following dependent nodes were not run")
             for subnode in info["dependents"]:
@@ -99,10 +96,10 @@ def create_pyscript(node, updatehash=False, store_exception=True):
     # pickle node
     timestamp = strftime("%Y%m%d_%H%M%S")
     if node._hierarchy:
-        suffix = "%s_%s_%s" % (timestamp, node._hierarchy, node._id)
+        suffix = f"{timestamp}_{node._hierarchy}_{node._id}"
         batch_dir = os.path.join(node.base_dir, node._hierarchy.split(".")[0], "batch")
     else:
-        suffix = "%s_%s" % (timestamp, node._id)
+        suffix = f"{timestamp}_{node._id}"
         batch_dir = os.path.join(node.base_dir, "batch")
     if not os.path.exists(batch_dir):
         os.makedirs(batch_dir)
@@ -176,6 +173,6 @@ except Exception as e:
 """
     cmdstr = cmdstr % (mpl_backend, pkl_file, batch_dir, node.config, suffix)
     pyscript = os.path.join(batch_dir, "pyscript_%s.py" % suffix)
-    with open(pyscript, "wt") as fp:
+    with open(pyscript, "w") as fp:
         fp.writelines(cmdstr)
     return pyscript
