@@ -1,7 +1,7 @@
 # Use duecredit (duecredit.org) to provide a citation to relevant work to
 # be cited. This does nothing, unless the user has duecredit installed,
 # And calls this with duecredit (as in `python -m duecredit script.py`):
-from .external.due import due, Doi, BibTeX
+from .external.due import due, Doi
 
 due.cite(
     Doi("10.3389/fninf.2011.00013"),
