@@ -1,9 +1,7 @@
-# -*- coding: utf-8 -*-
 """
 Utilities for the CLI functions.
 """
 
-
 import re
 import click
 import json
@@ -25,7 +23,7 @@ UnexistingFilePath = click.Path(dir_okay=False, resolve_path=True)
 # validators
 def check_not_none(ctx, param, value):
     if value is None:
-        raise click.BadParameter("got {}.".format(value))
+        raise click.BadParameter(f"got {value}.")
     return value
 
 
@@ -73,12 +71,12 @@ def add_args_options(arg_parser, interface):
             if not spec.is_trait_type(traits.TraitCompound):
                 trait_type = type(spec.trait_type.default_value)
             if trait_type in (bytes, str, int, float):
-                if trait_type == bytes:
+                if trait_type is bytes:
                     trait_type = str
                 args["type"] = trait_type
         elif len(spec.inner_traits) == 1:
             trait_type = type(spec.inner_traits[0].trait_type.default_value)
-            if trait_type == bytes:
+            if trait_type is bytes:
                 trait_type = str
             if trait_type in (bytes, bool, str, int, float):
                 args["type"] = trait_type
@@ -102,12 +100,10 @@ def add_args_options(arg_parser, interface):
 
             if has_multiple_inner_traits:
                 raise NotImplementedError(
-                    (
-                        "This interface cannot be used. via the"
-                        " command line as multiple inner traits"
-                        " are currently not supported for mandatory"
-                        " argument: {}.".format(name)
-                    )
+                    "This interface cannot be used. via the"
+                    " command line as multiple inner traits"
+                    " are currently not supported for mandatory"
+                    " argument: {}.".format(name)
                 )
             arg_parser.add_argument(name, help=desc, **args)
         else:
