@@ -1,11 +1,9 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Test testing utilities
 """
 
 import os
-import warnings
 import subprocess
 from unittest.mock import patch, MagicMock
 from unittest import SkipTest
@@ -15,7 +13,7 @@ from nipype.testing.utils import TempFATFS
 def test_tempfatfs():
     try:
         fatfs = TempFATFS()
-    except (IOError, OSError):
+    except OSError:
         raise SkipTest("Cannot mount FAT filesystems with FUSE")
     with fatfs as tmp_dir:
         assert os.path.exists(tmp_dir)
@@ -28,7 +26,7 @@ def test_tempfatfs():
 def test_tempfatfs_calledprocesserror():
     try:
         TempFATFS()
-    except IOError as e:
+    except OSError as e:
         assert isinstance(e, IOError)
         assert isinstance(e.__cause__, subprocess.CalledProcessError)
     else:
@@ -40,7 +38,7 @@ def test_tempfatfs_calledprocesserror():
 def test_tempfatfs_oserror():
     try:
         TempFATFS()
-    except IOError as e:
+    except OSError as e:
         assert isinstance(e, IOError)
         assert isinstance(e.__cause__, OSError)
     else:
