@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """
@@ -16,7 +15,6 @@ import atexit
 from warnings import warn
 from looseversion import LooseVersion
 import configparser
-import numpy as np
 
 from simplejson import load, dump
 
@@ -83,7 +81,7 @@ def mkdir_p(path):
             raise
 
 
-class NipypeConfig(object):
+class NipypeConfig:
     """Base nipype config class"""
 
     def __init__(self, *args, **kwargs):
@@ -207,7 +205,7 @@ class NipypeConfig(object):
         if not os.path.exists(self.data_file):
             return None
         with SoftFileLock("%s.lock" % self.data_file):
-            with open(self.data_file, "rt") as file:
+            with open(self.data_file) as file:
                 datadict = load(file)
         if key in datadict:
             return datadict[key]
@@ -218,14 +216,14 @@ class NipypeConfig(object):
         datadict = {}
         if os.path.exists(self.data_file):
             with SoftFileLock("%s.lock" % self.data_file):
-                with open(self.data_file, "rt") as file:
+                with open(self.data_file) as file:
                     datadict = load(file)
         else:
             dirname = os.path.dirname(self.data_file)
             if not os.path.exists(dirname):
                 mkdir_p(dirname)
         with SoftFileLock("%s.lock" % self.data_file):
-            with open(self.data_file, "wt") as file:
+            with open(self.data_file, "w") as file:
                 datadict[key] = value
                 dump(datadict, file)
 
@@ -354,7 +352,7 @@ class NipypeConfig(object):
 
             # Older versions of xvfbwrapper used vdisplay_num
             if not hasattr(self._display, "new_display"):
-                setattr(self._display, "new_display", self._display.vdisplay_num)
+                self._display.new_display = self._display.vdisplay_num
             return self.get_display()
 
     def stop_display(self):
