@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # emacs: -*- mode: python; py-indent-offset: 4; indent-tabs-mode: nil -*-
 # vi: set ft=python sts=4 ts=4 sw=4 et:
 """Miscellaneous utility functions
@@ -54,7 +53,7 @@ def trim(docstring, marker=None):
             if (
                 marker is not None
                 and stripped
-                and all([s == stripped[0] for s in stripped])
+                and all(s == stripped[0] for s in stripped)
                 and stripped[0] not in [":"]
             ):
                 line = line.replace(stripped[0], marker)
@@ -88,12 +87,7 @@ def is_container(item):
         True if container
         False if not (eg string)
     """
-    if isinstance(item, str):
-        return False
-    elif hasattr(item, "__iter__"):
-        return True
-    else:
-        return False
+    return not isinstance(item, str) and hasattr(item, "__iter__")
 
 
 def container_to_string(cont):
@@ -159,11 +153,11 @@ def package_check(
     """
 
     if app:
-        msg = "%s requires %s" % (app, pkg_name)
+        msg = f"{app} requires {pkg_name}"
     else:
         msg = "Nipype requires %s" % pkg_name
     if version:
-        msg += " with version >= %s" % (version,)
+        msg += f" with version >= {version}"
     try:
         mod = __import__(pkg_name)
     except ImportError as e:
@@ -247,10 +241,7 @@ def unflatten(in_list, prev_structure):
     if not isinstance(prev_structure, list):
         return next(in_list)
 
-    out = []
-    for item in prev_structure:
-        out.append(unflatten(in_list, item))
-    return out
+    return [unflatten(in_list, item) for item in prev_structure]
 
 
 def normalize_mc_params(params, source):
@@ -340,7 +331,7 @@ Diff between nipype inputs failed:
         old = _uniformize(dold[k])
 
         if new != old:
-            diff += ["  * %s: %r != %r" % (k, _shorten(new), _shorten(old))]
+            diff += [f"  * {k}: {_shorten(new)!r} != {_shorten(old)!r}"]
 
     if len(diff) > diffkeys:
         diff.insert(diffkeys, "Some dictionary entries had differing values:")
